svn commit: r292925 - in vendor/compiler-rt/dist: . cmake cmake/Modules include/sanitizer lib lib/asan lib/asan/scripts lib/asan/tests lib/builtins lib/builtins/Darwin-excludes lib/builtins/arm lib...

Dimitry Andric dim at FreeBSD.org
Wed Dec 30 11:52:21 UTC 2015


Author: dim
Date: Wed Dec 30 11:52:19 2015
New Revision: 292925
URL: https://svnweb.freebsd.org/changeset/base/292925

Log:
  Vendor import of compiler-rt trunk r256633:
  https://llvm.org/svn/llvm-project/compiler-rt/trunk@256633

Added:
  vendor/compiler-rt/dist/cmake/Modules/CompilerRTDarwinUtils.cmake
  vendor/compiler-rt/dist/lib/asan/.clang-format
  vendor/compiler-rt/dist/lib/builtins/Darwin-excludes/
  vendor/compiler-rt/dist/lib/builtins/Darwin-excludes/10.4-x86_64.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/Darwin-excludes/10.4.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/Darwin-excludes/CMakeLists.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/Darwin-excludes/README.TXT   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/Darwin-excludes/ios-armv7.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/Darwin-excludes/ios-armv7s.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/Darwin-excludes/ios.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/Darwin-excludes/ios6-armv7.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/Darwin-excludes/ios6-armv7s.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/Darwin-excludes/ios7-arm64.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/Darwin-excludes/iossim-i386.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/Darwin-excludes/iossim-x86_64.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/Darwin-excludes/iossim.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/Darwin-excludes/osx-i386.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/Darwin-excludes/osx-x86_64.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/Darwin-excludes/osx.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/arm/aeabi_cdcmp.S   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/arm/aeabi_cdcmpeq_check_nan.c   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/arm/aeabi_cfcmp.S   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/arm/aeabi_cfcmpeq_check_nan.c   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/arm/aeabi_drsub.c   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/arm/aeabi_frsub.c   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/divtc3.c   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/emutls.c   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/floatditf.c   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/floatunditf.c   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/i386/chkstk2.S   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/macho_embedded/
  vendor/compiler-rt/dist/lib/builtins/macho_embedded/CMakeLists.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/macho_embedded/arm.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/macho_embedded/common.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/macho_embedded/i386.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/macho_embedded/thumb2-64.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/macho_embedded/thumb2.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/multc3.c   (contents, props changed)
  vendor/compiler-rt/dist/lib/builtins/x86_64/chkstk2.S   (contents, props changed)
  vendor/compiler-rt/dist/lib/cfi/
  vendor/compiler-rt/dist/lib/cfi/CMakeLists.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/cfi/cfi.cc   (contents, props changed)
  vendor/compiler-rt/dist/lib/cfi/cfi_blacklist.txt   (contents, props changed)
  vendor/compiler-rt/dist/lib/dfsan/.clang-format
  vendor/compiler-rt/dist/lib/dfsan/dfsan_platform.h   (contents, props changed)
  vendor/compiler-rt/dist/lib/interception/.clang-format
  vendor/compiler-rt/dist/lib/lsan/.clang-format
  vendor/compiler-rt/dist/lib/msan/.clang-format
  vendor/compiler-rt/dist/lib/profile/InstrProfData.inc   (contents, props changed)
  vendor/compiler-rt/dist/lib/profile/InstrProfilingPlatformLinux.c   (contents, props changed)
  vendor/compiler-rt/dist/lib/profile/InstrProfilingPort.h   (contents, props changed)
  vendor/compiler-rt/dist/lib/profile/InstrProfilingValue.c   (contents, props changed)
  vendor/compiler-rt/dist/lib/profile/InstrProfilingWriter.c   (contents, props changed)
  vendor/compiler-rt/dist/lib/safestack/.clang-format
  vendor/compiler-rt/dist/lib/sanitizer_common/.clang-format
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_common_nolibc.cc   (contents, props changed)
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_malloc_mac.inc   (contents, props changed)
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_syscall_linux_aarch64.inc   (contents, props changed)
  vendor/compiler-rt/dist/lib/tsan/.clang-format
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_interceptors_mac.cc   (contents, props changed)
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_libdispatch_mac.cc   (contents, props changed)
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_malloc_mac.cc   (contents, props changed)
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_platform_posix.cc   (contents, props changed)
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_ppc_regs.h   (contents, props changed)
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_rtl_aarch64.S   (contents, props changed)
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_rtl_ppc64.S   (contents, props changed)
  vendor/compiler-rt/dist/lib/tsan/tests/rtl/tsan_test_util_posix.cc   (contents, props changed)
  vendor/compiler-rt/dist/lib/ubsan/ubsan_checks.inc   (contents, props changed)
  vendor/compiler-rt/dist/make/platform/clang_mingw.mk   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Darwin/abort_on_error.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/abort_on_error.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/activation-options.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/calloc-preload.c   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/init_fini_sections.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/mincore.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/pthread_create_version.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/asan-symbolize-bad-path.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/closed-fds.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/coverage-caller-callee.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/coverage-maybe-open-file.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/current_allocated_bytes.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/deep_call_stack.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/deep_thread_stack.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/dlclose-test.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/free_hook_realloc.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/freopen.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/gc-test.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/halt_on_error-signals.c   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/halt_on_error-torture.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/halt_on_error_suppress_equal_pcs.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/init-order-pthread-create.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/stack-overflow.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/stack-use-after-return.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/wait3.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/dll_control_c.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/fuse-lld.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/unsymbolized.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/halt_on_error-1.c   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/speculative_load.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/asan/TestCases/speculative_load2.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/builtins/Unit/arm/
  vendor/compiler-rt/dist/test/builtins/Unit/arm/aeabi_cdcmpeq_test.c   (contents, props changed)
  vendor/compiler-rt/dist/test/builtins/Unit/arm/aeabi_cdcmple_test.c   (contents, props changed)
  vendor/compiler-rt/dist/test/builtins/Unit/arm/aeabi_cfcmpeq_test.c   (contents, props changed)
  vendor/compiler-rt/dist/test/builtins/Unit/arm/aeabi_cfcmple_test.c   (contents, props changed)
  vendor/compiler-rt/dist/test/builtins/Unit/arm/aeabi_drsub_test.c   (contents, props changed)
  vendor/compiler-rt/dist/test/builtins/Unit/arm/aeabi_frsub_test.c   (contents, props changed)
  vendor/compiler-rt/dist/test/builtins/Unit/arm/call_apsr.S   (contents, props changed)
  vendor/compiler-rt/dist/test/builtins/Unit/arm/call_apsr.h   (contents, props changed)
  vendor/compiler-rt/dist/test/builtins/Unit/fixtfdi_test.c   (contents, props changed)
  vendor/compiler-rt/dist/test/builtins/Unit/fixtfti_test.c   (contents, props changed)
  vendor/compiler-rt/dist/test/builtins/Unit/fixunstfti_test.c   (contents, props changed)
  vendor/compiler-rt/dist/test/builtins/Unit/floatditf_test.c   (contents, props changed)
  vendor/compiler-rt/dist/test/builtins/Unit/floatunditf_test.c   (contents, props changed)
  vendor/compiler-rt/dist/test/cfi/base-derived-destructor.cpp   (contents, props changed)
  vendor/compiler-rt/dist/test/cfi/create-derivers.test
  vendor/compiler-rt/dist/test/cfi/cross-dso/
  vendor/compiler-rt/dist/test/cfi/cross-dso/icall/
  vendor/compiler-rt/dist/test/cfi/cross-dso/icall/icall-from-dso.cpp   (contents, props changed)
  vendor/compiler-rt/dist/test/cfi/cross-dso/icall/icall.cpp   (contents, props changed)
  vendor/compiler-rt/dist/test/cfi/cross-dso/icall/lit.local.cfg
  vendor/compiler-rt/dist/test/cfi/cross-dso/lit.local.cfg
  vendor/compiler-rt/dist/test/cfi/cross-dso/simple-fail.cpp   (contents, props changed)
  vendor/compiler-rt/dist/test/cfi/cross-dso/simple-pass.cpp   (contents, props changed)
  vendor/compiler-rt/dist/test/cfi/icall/
  vendor/compiler-rt/dist/test/cfi/icall/bad-signature.c   (contents, props changed)
  vendor/compiler-rt/dist/test/cfi/icall/external-call.c   (contents, props changed)
  vendor/compiler-rt/dist/test/cfi/icall/lit.local.cfg
  vendor/compiler-rt/dist/test/interception/
  vendor/compiler-rt/dist/test/lsan/TestCases/cleanup_in_tsd_destructor.c   (contents, props changed)
  vendor/compiler-rt/dist/test/lsan/TestCases/disabler.c   (contents, props changed)
  vendor/compiler-rt/dist/test/lsan/TestCases/disabler_in_tsd_destructor.c   (contents, props changed)
  vendor/compiler-rt/dist/test/lsan/TestCases/ignore_object.c   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/Linux/forkpty.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/Linux/mincore.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/Linux/process_vm_readv.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/allocator_mapping.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/ctermid.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/dlopen_executable.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/dtor-base-access.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/dtor-bit-fields.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/dtor-derived-class.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/dtor-member.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/dtor-multiple-inheritance-nontrivial-class-members.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/dtor-multiple-inheritance.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/dtor-trivial-class-members.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/dtor-trivial.cpp   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/dtor-vtable-multiple-inheritance.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/dtor-vtable.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/icmp_slt_allones.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/memcmp_test.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/msan_copy_shadow.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/pthread_setcancelstate.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/sem_getvalue.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/test.h   (contents, props changed)
  vendor/compiler-rt/dist/test/msan/use-after-dtor.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/profile/Inputs/instrprof-shared-lib.c   (contents, props changed)
  vendor/compiler-rt/dist/test/profile/Inputs/instrprof-shared-main.c   (contents, props changed)
  vendor/compiler-rt/dist/test/profile/instrprof-bufferio.c   (contents, props changed)
  vendor/compiler-rt/dist/test/profile/instrprof-error.c   (contents, props changed)
  vendor/compiler-rt/dist/test/profile/instrprof-shared.test
  vendor/compiler-rt/dist/test/profile/instrprof-value-prof-2.c   (contents, props changed)
  vendor/compiler-rt/dist/test/profile/instrprof-value-prof.c   (contents, props changed)
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/Darwin/
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/Darwin/abort_on_error.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/Darwin/lit.local.cfg
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/Linux/abort_on_error.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/Linux/fpe.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/Linux/ill.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/Linux/sem_init_glibc.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/fopen_nullptr.c   (contents, props changed)
  vendor/compiler-rt/dist/test/tsan/Darwin/
  vendor/compiler-rt/dist/test/tsan/Darwin/gcd-async-norace.mm
  vendor/compiler-rt/dist/test/tsan/Darwin/gcd-async-race.mm
  vendor/compiler-rt/dist/test/tsan/Darwin/gcd-groups-norace.mm
  vendor/compiler-rt/dist/test/tsan/Darwin/gcd-groups-stress.mm
  vendor/compiler-rt/dist/test/tsan/Darwin/gcd-once.mm
  vendor/compiler-rt/dist/test/tsan/Darwin/gcd-semaphore-norace.mm
  vendor/compiler-rt/dist/test/tsan/Darwin/gcd-serial-queue-norace.mm
  vendor/compiler-rt/dist/test/tsan/Darwin/gcd-sync-norace.mm
  vendor/compiler-rt/dist/test/tsan/Darwin/gcd-sync-race.mm
  vendor/compiler-rt/dist/test/tsan/Darwin/lit.local.cfg
  vendor/compiler-rt/dist/test/tsan/Darwin/objc-race.mm
  vendor/compiler-rt/dist/test/tsan/Darwin/objc-simple.mm
  vendor/compiler-rt/dist/test/tsan/Darwin/osspinlock-norace.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/tsan/Darwin/symbolizer-atos.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/tsan/Darwin/symbolizer-dladdr.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/tsan/Linux/check_memcpy.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/tsan/atomic_free3.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/tsan/fd_tid_recycled.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/tsan/memcmp_race.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/tsan/pie_test.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/tsan/race_stress.cc   (contents, props changed)
  vendor/compiler-rt/dist/test/ubsan/TestCases/Integer/suppressions.cpp   (contents, props changed)
  vendor/compiler-rt/dist/test/ubsan/TestCases/Misc/coverage-levels.cc   (contents, props changed)
Deleted:
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_symbolizer_process_libcdep.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_symbolizer_win.h
  vendor/compiler-rt/dist/lib/tsan/Makefile.old
  vendor/compiler-rt/dist/lib/tsan/check_memcpy.sh
  vendor/compiler-rt/dist/lib/tsan/rtl/Makefile.old
  vendor/compiler-rt/dist/lib/tsan/tests/rtl/tsan_test_util_linux.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Helpers/init-order-pthread-create-extra.cc
  vendor/compiler-rt/dist/test/asan/TestCases/closed-fds.cc
  vendor/compiler-rt/dist/test/asan/TestCases/coverage-caller-callee.cc
  vendor/compiler-rt/dist/test/asan/TestCases/coverage-maybe-open-file.cc
  vendor/compiler-rt/dist/test/asan/TestCases/current_allocated_bytes.cc
  vendor/compiler-rt/dist/test/asan/TestCases/deep_call_stack.cc
  vendor/compiler-rt/dist/test/asan/TestCases/deep_thread_stack.cc
  vendor/compiler-rt/dist/test/asan/TestCases/dlclose-test.cc
  vendor/compiler-rt/dist/test/asan/TestCases/free_hook_realloc.cc
  vendor/compiler-rt/dist/test/asan/TestCases/gc-test.cc
  vendor/compiler-rt/dist/test/asan/TestCases/init-order-pthread-create.cc
  vendor/compiler-rt/dist/test/asan/TestCases/stack-overflow.cc
  vendor/compiler-rt/dist/test/asan/TestCases/stack-use-after-return.cc
  vendor/compiler-rt/dist/test/lsan/TestCases/cleanup_in_tsd_destructor.cc
  vendor/compiler-rt/dist/test/lsan/TestCases/disabler_in_tsd_destructor.cc
  vendor/compiler-rt/dist/test/lsan/TestCases/ignore_object.cc
  vendor/compiler-rt/dist/test/tsan/test_output.sh
  vendor/compiler-rt/dist/test/ubsan/TestCases/Misc/Linux/coverage-levels.cc
Modified:
  vendor/compiler-rt/dist/CMakeLists.txt
  vendor/compiler-rt/dist/cmake/Modules/AddCompilerRT.cmake
  vendor/compiler-rt/dist/cmake/Modules/CompilerRTCompile.cmake
  vendor/compiler-rt/dist/cmake/Modules/CompilerRTUtils.cmake
  vendor/compiler-rt/dist/cmake/Modules/SanitizerUtils.cmake
  vendor/compiler-rt/dist/cmake/config-ix.cmake
  vendor/compiler-rt/dist/include/sanitizer/asan_interface.h
  vendor/compiler-rt/dist/include/sanitizer/common_interface_defs.h
  vendor/compiler-rt/dist/include/sanitizer/coverage_interface.h
  vendor/compiler-rt/dist/include/sanitizer/dfsan_interface.h
  vendor/compiler-rt/dist/include/sanitizer/lsan_interface.h
  vendor/compiler-rt/dist/include/sanitizer/msan_interface.h
  vendor/compiler-rt/dist/lib/CMakeLists.txt
  vendor/compiler-rt/dist/lib/asan/CMakeLists.txt
  vendor/compiler-rt/dist/lib/asan/README.txt
  vendor/compiler-rt/dist/lib/asan/asan_activation.cc
  vendor/compiler-rt/dist/lib/asan/asan_allocator.cc
  vendor/compiler-rt/dist/lib/asan/asan_allocator.h
  vendor/compiler-rt/dist/lib/asan/asan_debugging.cc
  vendor/compiler-rt/dist/lib/asan/asan_fake_stack.cc
  vendor/compiler-rt/dist/lib/asan/asan_flags.cc
  vendor/compiler-rt/dist/lib/asan/asan_flags.inc
  vendor/compiler-rt/dist/lib/asan/asan_globals.cc
  vendor/compiler-rt/dist/lib/asan/asan_init_version.h
  vendor/compiler-rt/dist/lib/asan/asan_interceptors.cc
  vendor/compiler-rt/dist/lib/asan/asan_interceptors.h
  vendor/compiler-rt/dist/lib/asan/asan_interface_internal.h
  vendor/compiler-rt/dist/lib/asan/asan_internal.h
  vendor/compiler-rt/dist/lib/asan/asan_linux.cc
  vendor/compiler-rt/dist/lib/asan/asan_mac.cc
  vendor/compiler-rt/dist/lib/asan/asan_malloc_linux.cc
  vendor/compiler-rt/dist/lib/asan/asan_malloc_mac.cc
  vendor/compiler-rt/dist/lib/asan/asan_mapping.h
  vendor/compiler-rt/dist/lib/asan/asan_new_delete.cc
  vendor/compiler-rt/dist/lib/asan/asan_poisoning.cc
  vendor/compiler-rt/dist/lib/asan/asan_posix.cc
  vendor/compiler-rt/dist/lib/asan/asan_report.cc
  vendor/compiler-rt/dist/lib/asan/asan_report.h
  vendor/compiler-rt/dist/lib/asan/asan_rtl.cc
  vendor/compiler-rt/dist/lib/asan/asan_stack.h
  vendor/compiler-rt/dist/lib/asan/asan_thread.cc
  vendor/compiler-rt/dist/lib/asan/asan_thread.h
  vendor/compiler-rt/dist/lib/asan/asan_win.cc
  vendor/compiler-rt/dist/lib/asan/asan_win_dll_thunk.cc
  vendor/compiler-rt/dist/lib/asan/asan_win_dynamic_runtime_thunk.cc
  vendor/compiler-rt/dist/lib/asan/scripts/asan_device_setup
  vendor/compiler-rt/dist/lib/asan/scripts/asan_symbolize.py
  vendor/compiler-rt/dist/lib/asan/tests/CMakeLists.txt
  vendor/compiler-rt/dist/lib/asan/tests/asan_asm_test.cc
  vendor/compiler-rt/dist/lib/asan/tests/asan_interface_test.cc
  vendor/compiler-rt/dist/lib/asan/tests/asan_mac_test.cc
  vendor/compiler-rt/dist/lib/asan/tests/asan_noinst_test.cc
  vendor/compiler-rt/dist/lib/asan/tests/asan_test.cc
  vendor/compiler-rt/dist/lib/asan/tests/asan_test_main.cc
  vendor/compiler-rt/dist/lib/builtins/CMakeLists.txt
  vendor/compiler-rt/dist/lib/builtins/README.txt
  vendor/compiler-rt/dist/lib/builtins/assembly.h
  vendor/compiler-rt/dist/lib/builtins/atomic.c
  vendor/compiler-rt/dist/lib/builtins/atomic_flag_clear.c
  vendor/compiler-rt/dist/lib/builtins/atomic_flag_clear_explicit.c
  vendor/compiler-rt/dist/lib/builtins/atomic_flag_test_and_set.c
  vendor/compiler-rt/dist/lib/builtins/atomic_flag_test_and_set_explicit.c
  vendor/compiler-rt/dist/lib/builtins/atomic_signal_fence.c
  vendor/compiler-rt/dist/lib/builtins/atomic_thread_fence.c
  vendor/compiler-rt/dist/lib/builtins/comparedf2.c
  vendor/compiler-rt/dist/lib/builtins/comparesf2.c
  vendor/compiler-rt/dist/lib/builtins/comparetf2.c
  vendor/compiler-rt/dist/lib/builtins/divdc3.c
  vendor/compiler-rt/dist/lib/builtins/divsc3.c
  vendor/compiler-rt/dist/lib/builtins/divxc3.c
  vendor/compiler-rt/dist/lib/builtins/enable_execute_stack.c
  vendor/compiler-rt/dist/lib/builtins/extendhfsf2.c
  vendor/compiler-rt/dist/lib/builtins/fixunsdfdi.c
  vendor/compiler-rt/dist/lib/builtins/fixunssfdi.c
  vendor/compiler-rt/dist/lib/builtins/floatdidf.c
  vendor/compiler-rt/dist/lib/builtins/floatsitf.c
  vendor/compiler-rt/dist/lib/builtins/floatundidf.c
  vendor/compiler-rt/dist/lib/builtins/fp_add_impl.inc
  vendor/compiler-rt/dist/lib/builtins/fp_extend.h
  vendor/compiler-rt/dist/lib/builtins/fp_extend_impl.inc
  vendor/compiler-rt/dist/lib/builtins/fp_fixint_impl.inc
  vendor/compiler-rt/dist/lib/builtins/fp_fixuint_impl.inc
  vendor/compiler-rt/dist/lib/builtins/fp_lib.h
  vendor/compiler-rt/dist/lib/builtins/fp_mul_impl.inc
  vendor/compiler-rt/dist/lib/builtins/fp_trunc.h
  vendor/compiler-rt/dist/lib/builtins/fp_trunc_impl.inc
  vendor/compiler-rt/dist/lib/builtins/gcc_personality_v0.c
  vendor/compiler-rt/dist/lib/builtins/i386/chkstk.S
  vendor/compiler-rt/dist/lib/builtins/int_lib.h
  vendor/compiler-rt/dist/lib/builtins/int_math.h
  vendor/compiler-rt/dist/lib/builtins/int_types.h
  vendor/compiler-rt/dist/lib/builtins/int_util.c
  vendor/compiler-rt/dist/lib/builtins/int_util.h
  vendor/compiler-rt/dist/lib/builtins/muldc3.c
  vendor/compiler-rt/dist/lib/builtins/mulsc3.c
  vendor/compiler-rt/dist/lib/builtins/mulxc3.c
  vendor/compiler-rt/dist/lib/builtins/ppc/DD.h
  vendor/compiler-rt/dist/lib/builtins/ppc/divtc3.c
  vendor/compiler-rt/dist/lib/builtins/ppc/multc3.c
  vendor/compiler-rt/dist/lib/builtins/subdf3.c
  vendor/compiler-rt/dist/lib/builtins/subsf3.c
  vendor/compiler-rt/dist/lib/builtins/truncdfhf2.c
  vendor/compiler-rt/dist/lib/builtins/truncsfhf2.c
  vendor/compiler-rt/dist/lib/builtins/x86_64/chkstk.S
  vendor/compiler-rt/dist/lib/dfsan/CMakeLists.txt
  vendor/compiler-rt/dist/lib/dfsan/dfsan.cc
  vendor/compiler-rt/dist/lib/dfsan/dfsan.h
  vendor/compiler-rt/dist/lib/dfsan/dfsan_custom.cc
  vendor/compiler-rt/dist/lib/dfsan/done_abilist.txt
  vendor/compiler-rt/dist/lib/interception/interception_linux.h
  vendor/compiler-rt/dist/lib/interception/interception_win.cc
  vendor/compiler-rt/dist/lib/interception/interception_win.h
  vendor/compiler-rt/dist/lib/lsan/CMakeLists.txt
  vendor/compiler-rt/dist/lib/lsan/lsan.cc
  vendor/compiler-rt/dist/lib/lsan/lsan_allocator.cc
  vendor/compiler-rt/dist/lib/lsan/lsan_common.cc
  vendor/compiler-rt/dist/lib/lsan/lsan_common.h
  vendor/compiler-rt/dist/lib/lsan/lsan_common_linux.cc
  vendor/compiler-rt/dist/lib/lsan/lsan_flags.inc
  vendor/compiler-rt/dist/lib/lsan/lsan_interceptors.cc
  vendor/compiler-rt/dist/lib/lsan/lsan_thread.cc
  vendor/compiler-rt/dist/lib/msan/CMakeLists.txt
  vendor/compiler-rt/dist/lib/msan/msan.cc
  vendor/compiler-rt/dist/lib/msan/msan.h
  vendor/compiler-rt/dist/lib/msan/msan_allocator.cc
  vendor/compiler-rt/dist/lib/msan/msan_chained_origin_depot.cc
  vendor/compiler-rt/dist/lib/msan/msan_flags.inc
  vendor/compiler-rt/dist/lib/msan/msan_interceptors.cc
  vendor/compiler-rt/dist/lib/msan/msan_interface_internal.h
  vendor/compiler-rt/dist/lib/msan/msan_linux.cc
  vendor/compiler-rt/dist/lib/msan/msan_new_delete.cc
  vendor/compiler-rt/dist/lib/msan/msan_thread.h
  vendor/compiler-rt/dist/lib/msan/tests/CMakeLists.txt
  vendor/compiler-rt/dist/lib/msan/tests/msan_test.cc
  vendor/compiler-rt/dist/lib/profile/CMakeLists.txt
  vendor/compiler-rt/dist/lib/profile/InstrProfiling.c
  vendor/compiler-rt/dist/lib/profile/InstrProfiling.h
  vendor/compiler-rt/dist/lib/profile/InstrProfilingBuffer.c
  vendor/compiler-rt/dist/lib/profile/InstrProfilingFile.c
  vendor/compiler-rt/dist/lib/profile/InstrProfilingInternal.h
  vendor/compiler-rt/dist/lib/profile/InstrProfilingPlatformDarwin.c
  vendor/compiler-rt/dist/lib/profile/InstrProfilingPlatformOther.c
  vendor/compiler-rt/dist/lib/profile/InstrProfilingRuntime.cc
  vendor/compiler-rt/dist/lib/profile/InstrProfilingUtil.c
  vendor/compiler-rt/dist/lib/safestack/CMakeLists.txt
  vendor/compiler-rt/dist/lib/safestack/safestack.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/CMakeLists.txt
  vendor/compiler-rt/dist/lib/sanitizer_common/Makefile.mk
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_addrhashmap.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_allocator.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_allocator.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_allocator_internal.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_asm.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_atomic.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_common.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_common.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_common_interceptors.inc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_common_interceptors_format.inc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_common_interceptors_ioctl.inc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_common_libcdep.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_common_syscalls.inc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_coverage_libcdep.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_coverage_mapping_libcdep.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_deadlock_detector1.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_deadlock_detector_interface.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_flag_parser.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_flag_parser.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_flags.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_flags.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_flags.inc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_interface_internal.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_internal_defs.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_lfstack.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_libc.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_libc.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_libignore.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_linux.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_linux.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_linux_libcdep.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_list.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_mac.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_mac.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_persistent_allocator.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_platform.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_platform_interceptors.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_platform_limits_posix.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_platform_limits_posix.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_posix.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_posix.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_posix_libcdep.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_printf.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_procmaps_common.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_procmaps_linux.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_procmaps_mac.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_quarantine.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_stackdepot.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_stackdepot.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_stackdepotbase.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_stacktrace.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_stacktrace.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_stacktrace_printer.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_stoptheworld_linux_libcdep.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_suppressions.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_suppressions.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_symbolizer_internal.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_symbolizer_libbacktrace.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_symbolizer_libcdep.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_symbolizer_mac.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_symbolizer_posix_libcdep.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_symbolizer_win.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_thread_registry.h
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_tls_get_addr.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/sanitizer_win.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/scripts/gen_dynamic_list.py
  vendor/compiler-rt/dist/lib/sanitizer_common/tests/CMakeLists.txt
  vendor/compiler-rt/dist/lib/sanitizer_common/tests/sanitizer_allocator_test.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/tests/sanitizer_common_test.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/tests/sanitizer_libc_test.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/tests/sanitizer_linux_test.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/tests/sanitizer_stacktrace_test.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/tests/sanitizer_suppressions_test.cc
  vendor/compiler-rt/dist/lib/sanitizer_common/tests/sanitizer_test_main.cc
  vendor/compiler-rt/dist/lib/tsan/CMakeLists.txt
  vendor/compiler-rt/dist/lib/tsan/analyze_libtsan.sh
  vendor/compiler-rt/dist/lib/tsan/check_analyze.sh
  vendor/compiler-rt/dist/lib/tsan/dd/CMakeLists.txt
  vendor/compiler-rt/dist/lib/tsan/go/buildgo.sh
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_clock.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_defs.h
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_dense_alloc.h
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_flags.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_flags.inc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_interceptors.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_interceptors.h
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_interface_ann.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_mman.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_mman.h
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_mutex.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_mutex.h
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_new_delete.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_platform.h
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_platform_linux.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_platform_mac.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_platform_windows.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_report.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_rtl.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_rtl.h
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_rtl_amd64.S
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_rtl_mutex.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_rtl_report.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_rtl_thread.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_stat.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_stat.h
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_suppressions.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_symbolize.cc
  vendor/compiler-rt/dist/lib/tsan/rtl/tsan_sync.h
  vendor/compiler-rt/dist/lib/tsan/tests/CMakeLists.txt
  vendor/compiler-rt/dist/lib/tsan/tests/rtl/CMakeLists.txt
  vendor/compiler-rt/dist/lib/tsan/tests/rtl/tsan_posix.cc
  vendor/compiler-rt/dist/lib/tsan/tests/rtl/tsan_test.cc
  vendor/compiler-rt/dist/lib/tsan/tests/rtl/tsan_test_util.h
  vendor/compiler-rt/dist/lib/tsan/tests/unit/tsan_clock_test.cc
  vendor/compiler-rt/dist/lib/tsan/tests/unit/tsan_flags_test.cc
  vendor/compiler-rt/dist/lib/tsan/tests/unit/tsan_mman_test.cc
  vendor/compiler-rt/dist/lib/ubsan/CMakeLists.txt
  vendor/compiler-rt/dist/lib/ubsan/ubsan_diag.cc
  vendor/compiler-rt/dist/lib/ubsan/ubsan_diag.h
  vendor/compiler-rt/dist/lib/ubsan/ubsan_flags.cc
  vendor/compiler-rt/dist/lib/ubsan/ubsan_flags.inc
  vendor/compiler-rt/dist/lib/ubsan/ubsan_handlers.cc
  vendor/compiler-rt/dist/lib/ubsan/ubsan_handlers.h
  vendor/compiler-rt/dist/lib/ubsan/ubsan_handlers_cxx.cc
  vendor/compiler-rt/dist/make/platform/clang_darwin.mk
  vendor/compiler-rt/dist/make/platform/clang_darwin_test_input.c
  vendor/compiler-rt/dist/make/platform/clang_linux.mk
  vendor/compiler-rt/dist/test/CMakeLists.txt
  vendor/compiler-rt/dist/test/asan/CMakeLists.txt
  vendor/compiler-rt/dist/test/asan/TestCases/Android/coverage-android.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Darwin/atos-symbolizer-dyld-root-path.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Darwin/atos-symbolizer.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Darwin/crashlog-stacktraces.c
  vendor/compiler-rt/dist/test/asan/TestCases/Darwin/dladdr-demangling.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Darwin/dyld_insert_libraries_reexec.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Darwin/interface_symbols_darwin.c
  vendor/compiler-rt/dist/test/asan/TestCases/Darwin/suppressions-darwin.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Darwin/suppressions-sandbox.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/asan_prelink_test.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/coverage-missing.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/init-order-dlopen.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/initialization-bug-any-order.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/interface_symbols_linux.c
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/kernel-area.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/leak.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/malloc-in-qsort.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/malloc_delete_mismatch.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/nohugepage_test.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/odr-violation.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/overflow-in-qsort.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/ptrace.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/quarantine_size_mb.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/read_binary_name_regtest.c
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/sized_delete_test.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/stack-overflow-sigbus.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/stack-trace-dlclose.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/static_tls.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Linux/stress_dtls.c
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/allow_user_segv.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/asan-symbolize-sanity-test.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/assign_large_valloc_to_global.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/coverage-direct-activation.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/coverage-direct-large.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/coverage-direct.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/coverage-fork-direct.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/coverage-fork.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/coverage-module-unloaded.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/coverage-sandboxing.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/coverage.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/ioctl.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/large_allocator_unpoisons_on_free.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/log_path_fork_test.cc.disabled
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/new_array_cookie_test.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/new_array_cookie_uaf_test.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/new_array_cookie_with_new_from_class.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/start-deactivated.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/tsd_dtor_leak.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Posix/wait.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/bitfield_uaf.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/coverage-basic.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/demangled_names.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/dll_noreturn.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/dll_poison_unpoison.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/dll_report_globals_symbolization_at_startup.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/dll_stack_use_after_return.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/dll_thread_stack_array_left_oob.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/intercept_strdup.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/null_deref.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/operator_delete_wrong_argument.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/operator_new_left_oob.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/operator_new_right_oob.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/operator_new_uaf.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/queue_user_work_item_report.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/report_after_syminitialize.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/report_globals_reload_dll.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/report_globals_vs_freelibrary.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/seh.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/shadow_mapping_failure.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/stack_use_after_return.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/symbols_path.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/thread_stack_array_left_oob.cc
  vendor/compiler-rt/dist/test/asan/TestCases/Windows/thread_stack_array_right_oob.cc
  vendor/compiler-rt/dist/test/asan/TestCases/alloca_loop_unpoisoning.cc
  vendor/compiler-rt/dist/test/asan/TestCases/alloca_vla_interact.cc
  vendor/compiler-rt/dist/test/asan/TestCases/allocator_returns_null.cc
  vendor/compiler-rt/dist/test/asan/TestCases/asan_and_llvm_coverage_test.cc
  vendor/compiler-rt/dist/test/asan/TestCases/asan_options-help.cc
  vendor/compiler-rt/dist/test/asan/TestCases/atexit_stats.cc
  vendor/compiler-rt/dist/test/asan/TestCases/atoi_strict.c
  vendor/compiler-rt/dist/test/asan/TestCases/atol_strict.c
  vendor/compiler-rt/dist/test/asan/TestCases/atoll_strict.c
  vendor/compiler-rt/dist/test/asan/TestCases/contiguous_container.cc
  vendor/compiler-rt/dist/test/asan/TestCases/contiguous_container_crash.cc
  vendor/compiler-rt/dist/test/asan/TestCases/coverage-and-lsan.cc
  vendor/compiler-rt/dist/test/asan/TestCases/coverage-caller-callee-total-count.cc
  vendor/compiler-rt/dist/test/asan/TestCases/coverage-disabled.cc
  vendor/compiler-rt/dist/test/asan/TestCases/coverage-levels.cc
  vendor/compiler-rt/dist/test/asan/TestCases/coverage-order-pcs.cc
  vendor/compiler-rt/dist/test/asan/TestCases/coverage-reset.cc
  vendor/compiler-rt/dist/test/asan/TestCases/coverage-tracing.cc
  vendor/compiler-rt/dist/test/asan/TestCases/debug_mapping.cc
  vendor/compiler-rt/dist/test/asan/TestCases/debug_ppc64_mapping.cc
  vendor/compiler-rt/dist/test/asan/TestCases/debug_report.cc
  vendor/compiler-rt/dist/test/asan/TestCases/debug_stacks.cc
  vendor/compiler-rt/dist/test/asan/TestCases/deep_stack_uaf.cc
  vendor/compiler-rt/dist/test/asan/TestCases/double-free.cc
  vendor/compiler-rt/dist/test/asan/TestCases/dump_instruction_bytes.cc
  vendor/compiler-rt/dist/test/asan/TestCases/heap-overflow.cc
  vendor/compiler-rt/dist/test/asan/TestCases/heavy_uar_test.cc
  vendor/compiler-rt/dist/test/asan/TestCases/init-order-atexit.cc
  vendor/compiler-rt/dist/test/asan/TestCases/initialization-blacklist.cc
  vendor/compiler-rt/dist/test/asan/TestCases/initialization-bug.cc
  vendor/compiler-rt/dist/test/asan/TestCases/initialization-constexpr.cc
  vendor/compiler-rt/dist/test/asan/TestCases/initialization-nobug.cc
  vendor/compiler-rt/dist/test/asan/TestCases/interception_failure_test.cc
  vendor/compiler-rt/dist/test/asan/TestCases/invalid-free.cc
  vendor/compiler-rt/dist/test/asan/TestCases/log-path_test.cc
  vendor/compiler-rt/dist/test/asan/TestCases/malloc_context_size.cc
  vendor/compiler-rt/dist/test/asan/TestCases/malloc_fill.cc
  vendor/compiler-rt/dist/test/asan/TestCases/max_redzone.cc
  vendor/compiler-rt/dist/test/asan/TestCases/memcmp_strict_test.cc
  vendor/compiler-rt/dist/test/asan/TestCases/mmap_limit_mb.cc
  vendor/compiler-rt/dist/test/asan/TestCases/null_deref.cc
  vendor/compiler-rt/dist/test/asan/TestCases/on_error_callback.cc
  vendor/compiler-rt/dist/test/asan/TestCases/poison_partial.cc
  vendor/compiler-rt/dist/test/asan/TestCases/print_summary.cc
  vendor/compiler-rt/dist/test/asan/TestCases/printf-1.c
  vendor/compiler-rt/dist/test/asan/TestCases/printf-2.c
  vendor/compiler-rt/dist/test/asan/TestCases/printf-3.c
  vendor/compiler-rt/dist/test/asan/TestCases/printf-4.c
  vendor/compiler-rt/dist/test/asan/TestCases/printf-5.c
  vendor/compiler-rt/dist/test/asan/TestCases/sleep_before_dying.c
  vendor/compiler-rt/dist/test/asan/TestCases/stack-oob-frames.cc
  vendor/compiler-rt/dist/test/asan/TestCases/strcasestr-1.c
  vendor/compiler-rt/dist/test/asan/TestCases/strcasestr-2.c
  vendor/compiler-rt/dist/test/asan/TestCases/strcasestr_strict.c
  vendor/compiler-rt/dist/test/asan/TestCases/strcat_strict.c
  vendor/compiler-rt/dist/test/asan/TestCases/strchr_strict.c
  vendor/compiler-rt/dist/test/asan/TestCases/strcmp_strict.c
  vendor/compiler-rt/dist/test/asan/TestCases/strcspn-1.c
  vendor/compiler-rt/dist/test/asan/TestCases/strcspn-2.c
  vendor/compiler-rt/dist/test/asan/TestCases/strcspn_strict.c
  vendor/compiler-rt/dist/test/asan/TestCases/strip_path_prefix.c
  vendor/compiler-rt/dist/test/asan/TestCases/strncat_strict.c
  vendor/compiler-rt/dist/test/asan/TestCases/strpbrk-1.c
  vendor/compiler-rt/dist/test/asan/TestCases/strpbrk-2.c
  vendor/compiler-rt/dist/test/asan/TestCases/strpbrk_strict.c
  vendor/compiler-rt/dist/test/asan/TestCases/strspn-1.c
  vendor/compiler-rt/dist/test/asan/TestCases/strspn-2.c
  vendor/compiler-rt/dist/test/asan/TestCases/strspn_strict.c
  vendor/compiler-rt/dist/test/asan/TestCases/strstr-1.c
  vendor/compiler-rt/dist/test/asan/TestCases/strstr-2.c
  vendor/compiler-rt/dist/test/asan/TestCases/strstr_strict.c
  vendor/compiler-rt/dist/test/asan/TestCases/strtol_strict.c
  vendor/compiler-rt/dist/test/asan/TestCases/strtoll_strict.c
  vendor/compiler-rt/dist/test/asan/TestCases/suppressions-exec-relative-location.cc
  vendor/compiler-rt/dist/test/asan/TestCases/suppressions-function.cc
  vendor/compiler-rt/dist/test/asan/TestCases/suppressions-interceptor.cc
  vendor/compiler-rt/dist/test/asan/TestCases/suppressions-library.cc
  vendor/compiler-rt/dist/test/asan/TestCases/throw_call_test.cc
  vendor/compiler-rt/dist/test/asan/TestCases/uar_and_exceptions.cc
  vendor/compiler-rt/dist/test/asan/TestCases/use-after-poison.cc
  vendor/compiler-rt/dist/test/asan/TestCases/use-after-scope.cc
  vendor/compiler-rt/dist/test/asan/TestCases/verbose-log-path_test.cc
  vendor/compiler-rt/dist/test/asan/TestCases/zero_page_pc.cc
  vendor/compiler-rt/dist/test/asan/android_commands/android_run.py
  vendor/compiler-rt/dist/test/asan/lit.cfg
  vendor/compiler-rt/dist/test/builtins/Unit/divtc3_test.c
  vendor/compiler-rt/dist/test/builtins/Unit/fixtfsi_test.c
  vendor/compiler-rt/dist/test/builtins/Unit/fixunsdfdi_test.c
  vendor/compiler-rt/dist/test/builtins/Unit/fixunsdfsi_test.c
  vendor/compiler-rt/dist/test/builtins/Unit/fixunsdfti_test.c
  vendor/compiler-rt/dist/test/builtins/Unit/fixunssfdi_test.c
  vendor/compiler-rt/dist/test/builtins/Unit/fixunssfsi_test.c
  vendor/compiler-rt/dist/test/builtins/Unit/fixunstfdi_test.c
  vendor/compiler-rt/dist/test/builtins/Unit/fixunstfsi_test.c
  vendor/compiler-rt/dist/test/builtins/Unit/floatsitf_test.c
  vendor/compiler-rt/dist/test/builtins/Unit/multc3_test.c
  vendor/compiler-rt/dist/test/builtins/Unit/multf3_test.c
  vendor/compiler-rt/dist/test/cfi/CMakeLists.txt
  vendor/compiler-rt/dist/test/cfi/anon-namespace.cpp
  vendor/compiler-rt/dist/test/cfi/bad-cast.cpp
  vendor/compiler-rt/dist/test/cfi/lit.cfg
  vendor/compiler-rt/dist/test/cfi/multiple-inheritance.cpp
  vendor/compiler-rt/dist/test/cfi/nvcall.cpp
  vendor/compiler-rt/dist/test/cfi/overwrite.cpp
  vendor/compiler-rt/dist/test/cfi/sibling.cpp
  vendor/compiler-rt/dist/test/cfi/simple-fail.cpp
  vendor/compiler-rt/dist/test/cfi/utils.h
  vendor/compiler-rt/dist/test/cfi/vdtor.cpp
  vendor/compiler-rt/dist/test/lit.common.cfg
  vendor/compiler-rt/dist/test/lit.common.configured.in
  vendor/compiler-rt/dist/test/lsan/TestCases/disabler.cc
  vendor/compiler-rt/dist/test/lsan/TestCases/suppressions_file.cc
  vendor/compiler-rt/dist/test/msan/Linux/mallinfo.cc
  vendor/compiler-rt/dist/test/msan/dlerror.cc
  vendor/compiler-rt/dist/test/msan/insertvalue_origin.cc
  vendor/compiler-rt/dist/test/msan/mmap.cc
  vendor/compiler-rt/dist/test/msan/mmap_below_shadow.cc
  vendor/compiler-rt/dist/test/msan/param_tls_limit.cc
  vendor/compiler-rt/dist/test/msan/signal_stress_test.cc
  vendor/compiler-rt/dist/test/msan/strlen_of_shadow.cc
  vendor/compiler-rt/dist/test/profile/instrprof-without-libc.c
  vendor/compiler-rt/dist/test/safestack/lit.cfg
  vendor/compiler-rt/dist/test/safestack/overflow.c
  vendor/compiler-rt/dist/test/sanitizer_common/CMakeLists.txt
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/Linux/assert.cc
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/Linux/getpass.cc
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/Linux/hard_rss_limit_mb_test.cc
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/Linux/open_memstream.cc
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/Linux/ptrace.cc
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/Linux/sanitizer_set_death_callback_test.cc
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/Linux/soft_rss_limit_mb_test.cc
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/Posix/decorate_proc_maps.cc
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/options-help.cc
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/options-include.cc
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/options-invalid.cc
  vendor/compiler-rt/dist/test/sanitizer_common/TestCases/print-stack-trace.cc
  vendor/compiler-rt/dist/test/sanitizer_common/lit.common.cfg
  vendor/compiler-rt/dist/test/tsan/CMakeLists.txt
  vendor/compiler-rt/dist/test/tsan/allocator_returns_null.cc
  vendor/compiler-rt/dist/test/tsan/barrier.cc
  vendor/compiler-rt/dist/test/tsan/bench_acquire_only.cc
  vendor/compiler-rt/dist/test/tsan/bench_acquire_release.cc
  vendor/compiler-rt/dist/test/tsan/bench_local_mutex.cc
  vendor/compiler-rt/dist/test/tsan/bench_mutex.cc
  vendor/compiler-rt/dist/test/tsan/bench_release_only.cc
  vendor/compiler-rt/dist/test/tsan/bench_rwmutex.cc
  vendor/compiler-rt/dist/test/tsan/bench_single_writer.cc
  vendor/compiler-rt/dist/test/tsan/bench_ten_mutexes.cc
  vendor/compiler-rt/dist/test/tsan/cond_cancel.c
  vendor/compiler-rt/dist/test/tsan/cond_version.c
  vendor/compiler-rt/dist/test/tsan/deadlock_detector_stress_test.cc
  vendor/compiler-rt/dist/test/tsan/dl_iterate_phdr.cc
  vendor/compiler-rt/dist/test/tsan/dlclose.cc
  vendor/compiler-rt/dist/test/tsan/fork_atexit.cc
  vendor/compiler-rt/dist/test/tsan/fork_deadlock.cc
  vendor/compiler-rt/dist/test/tsan/fork_multithreaded.cc
  vendor/compiler-rt/dist/test/tsan/fork_multithreaded3.cc
  vendor/compiler-rt/dist/test/tsan/free_race.c
  vendor/compiler-rt/dist/test/tsan/getline_nohang.cc
  vendor/compiler-rt/dist/test/tsan/global_race.cc
  vendor/compiler-rt/dist/test/tsan/global_race2.cc
  vendor/compiler-rt/dist/test/tsan/global_race3.cc
  vendor/compiler-rt/dist/test/tsan/halt_on_error.cc
  vendor/compiler-rt/dist/test/tsan/ignore_lib0.cc
  vendor/compiler-rt/dist/test/tsan/ignore_lib1.cc
  vendor/compiler-rt/dist/test/tsan/ignore_lib2.cc
  vendor/compiler-rt/dist/test/tsan/ignore_lib3.cc
  vendor/compiler-rt/dist/test/tsan/inlined_memcpy_race.cc
  vendor/compiler-rt/dist/test/tsan/java_race_pc.cc
  vendor/compiler-rt/dist/test/tsan/lit.cfg
  vendor/compiler-rt/dist/test/tsan/load_shared_lib.cc
  vendor/compiler-rt/dist/test/tsan/malloc_overflow.cc
  vendor/compiler-rt/dist/test/tsan/map32bit.cc
  vendor/compiler-rt/dist/test/tsan/memcpy_race.cc
  vendor/compiler-rt/dist/test/tsan/mmap_large.cc
  vendor/compiler-rt/dist/test/tsan/mop_with_offset.cc
  vendor/compiler-rt/dist/test/tsan/mop_with_offset2.cc
  vendor/compiler-rt/dist/test/tsan/mutex_cycle2.c
  vendor/compiler-rt/dist/test/tsan/mutexset1.cc
  vendor/compiler-rt/dist/test/tsan/mutexset2.cc
  vendor/compiler-rt/dist/test/tsan/mutexset3.cc
  vendor/compiler-rt/dist/test/tsan/mutexset4.cc
  vendor/compiler-rt/dist/test/tsan/mutexset5.cc
  vendor/compiler-rt/dist/test/tsan/mutexset6.cc
  vendor/compiler-rt/dist/test/tsan/mutexset8.cc
  vendor/compiler-rt/dist/test/tsan/pthread_atfork_deadlock.c
  vendor/compiler-rt/dist/test/tsan/race_on_barrier.c
  vendor/compiler-rt/dist/test/tsan/race_on_barrier2.c
  vendor/compiler-rt/dist/test/tsan/race_on_heap.cc
  vendor/compiler-rt/dist/test/tsan/race_on_mutex.c
  vendor/compiler-rt/dist/test/tsan/race_on_speculative_load.cc
  vendor/compiler-rt/dist/test/tsan/race_top_suppression.cc
  vendor/compiler-rt/dist/test/tsan/race_top_suppression1.cc
  vendor/compiler-rt/dist/test/tsan/real_deadlock_detector_stress_test.cc
  vendor/compiler-rt/dist/test/tsan/setuid2.c
  vendor/compiler-rt/dist/test/tsan/signal_cond.cc
  vendor/compiler-rt/dist/test/tsan/signal_errno.cc
  vendor/compiler-rt/dist/test/tsan/signal_longjmp.cc
  vendor/compiler-rt/dist/test/tsan/signal_recursive.cc
  vendor/compiler-rt/dist/test/tsan/signal_reset.cc
  vendor/compiler-rt/dist/test/tsan/signal_sync.cc
  vendor/compiler-rt/dist/test/tsan/signal_thread.cc
  vendor/compiler-rt/dist/test/tsan/stack_sync_reuse.cc
  vendor/compiler-rt/dist/test/tsan/suppressions_global.cc
  vendor/compiler-rt/dist/test/tsan/suppressions_race.cc
  vendor/compiler-rt/dist/test/tsan/suppressions_race2.cc
  vendor/compiler-rt/dist/test/tsan/test.h
  vendor/compiler-rt/dist/test/tsan/thread_name2.cc
  vendor/compiler-rt/dist/test/tsan/tls_race.cc
  vendor/compiler-rt/dist/test/tsan/tls_race2.cc
  vendor/compiler-rt/dist/test/tsan/vfork.cc
  vendor/compiler-rt/dist/test/tsan/virtual_inheritance_compile_bug.cc
  vendor/compiler-rt/dist/test/tsan/vptr_benign_race.cc
  vendor/compiler-rt/dist/test/ubsan/CMakeLists.txt
  vendor/compiler-rt/dist/test/ubsan/TestCases/Float/cast-overflow.cpp
  vendor/compiler-rt/dist/test/ubsan/TestCases/Integer/summary.cpp
  vendor/compiler-rt/dist/test/ubsan/TestCases/Misc/Linux/ubsan_options.cc
  vendor/compiler-rt/dist/test/ubsan/TestCases/Misc/bool.cpp
  vendor/compiler-rt/dist/test/ubsan/TestCases/Misc/log-path_test.cc
  vendor/compiler-rt/dist/test/ubsan/TestCases/Misc/missing_return.cpp
  vendor/compiler-rt/dist/test/ubsan/TestCases/Misc/nonnull-arg.cpp
  vendor/compiler-rt/dist/test/ubsan/TestCases/TypeCheck/Function/function.cpp
  vendor/compiler-rt/dist/test/ubsan/TestCases/TypeCheck/misaligned.cpp
  vendor/compiler-rt/dist/test/ubsan/TestCases/TypeCheck/vptr.cpp
  vendor/compiler-rt/dist/test/ubsan/lit.common.cfg

Modified: vendor/compiler-rt/dist/CMakeLists.txt
==============================================================================
--- vendor/compiler-rt/dist/CMakeLists.txt	Wed Dec 30 11:51:35 2015	(r292924)
+++ vendor/compiler-rt/dist/CMakeLists.txt	Wed Dec 30 11:52:19 2015	(r292925)
@@ -9,7 +9,7 @@
 
 # Check if compiler-rt is built as a standalone project.
 if (CMAKE_SOURCE_DIR STREQUAL CMAKE_CURRENT_SOURCE_DIR)
-  project(CompilerRT C CXX)
+  project(CompilerRT C CXX ASM)
   set(COMPILER_RT_STANDALONE_BUILD TRUE)
 else()
   set(COMPILER_RT_STANDALONE_BUILD FALSE)
@@ -22,7 +22,7 @@ endif()
 if (NOT MSVC)
   cmake_minimum_required(VERSION 2.8.8)
 else()
-  # Version 2.8.12.1 is required to build with Visual Studion 2013.
+  # Version 2.8.12.1 is required to build with Visual Studio 2013.
   cmake_minimum_required(VERSION 2.8.12.1)
 endif()
 
@@ -43,6 +43,11 @@ endif()
 # Top level target used to build all compiler-rt libraries.
 add_custom_target(compiler-rt ALL)
 
+option(COMPILER_RT_BUILD_BUILTINS "Build builtins" ON)
+mark_as_advanced(COMPILER_RT_BUILD_BUILTINS)
+option(COMPILER_RT_BUILD_SANITIZERS "Build sanitizers" ON)
+mark_as_advanced(COMPILER_RT_BUILD_SANITIZERS)
+
 if (NOT COMPILER_RT_STANDALONE_BUILD)
   # Compute the Clang version from the LLVM version.
   # FIXME: We should be able to reuse CLANG_VERSION variable calculated
@@ -132,22 +137,27 @@ else()
   set(COMPILER_RT_TEST_COMPILER_ID GNU)
 endif()
 
-# Tests using XFAIL use the first value in COMPILER_RT_TEST_TARGET_TRIPLE
-set(COMPILER_RT_TEST_TARGET_TRIPLE ${TARGET_TRIPLE} CACHE STRING
-    "Default triple for cross-compiled executables")
-string(REPLACE "-" ";" TARGET_TRIPLE_LIST ${COMPILER_RT_TEST_TARGET_TRIPLE})
-list(GET TARGET_TRIPLE_LIST 0 COMPILER_RT_TEST_TARGET_ARCH)
-list(GET TARGET_TRIPLE_LIST 1 COMPILER_RT_TEST_TARGET_OS)
-list(GET TARGET_TRIPLE_LIST 2 COMPILER_RT_TEST_TARGET_ABI)
+set(COMPILER_RT_DEFAULT_TARGET_TRIPLE ${TARGET_TRIPLE} CACHE STRING
+    "Default triple for which compiler-rt runtimes will be built.")
+if(DEFINED COMPILER_RT_TEST_TARGET_TRIPLE)
+  # Backwards compatibility: this variable used to be called
+  # COMPILER_RT_TEST_TARGET_TRIPLE.
+  set(COMPILER_RT_DEFAULT_TARGET_TRIPLE ${COMPILER_RT_TEST_TARGET_TRIPLE})
+endif()
+
+string(REPLACE "-" ";" TARGET_TRIPLE_LIST ${COMPILER_RT_DEFAULT_TARGET_TRIPLE})
+list(GET TARGET_TRIPLE_LIST 0 COMPILER_RT_DEFAULT_TARGET_ARCH)
+list(GET TARGET_TRIPLE_LIST 1 COMPILER_RT_DEFAULT_TARGET_OS)
+list(GET TARGET_TRIPLE_LIST 2 COMPILER_RT_DEFAULT_TARGET_ABI)
 # Determine if test target triple is specified explicitly, and doesn't match the
 # default.
-if(NOT COMPILER_RT_TEST_TARGET_TRIPLE STREQUAL TARGET_TRIPLE)
-  set(COMPILER_RT_HAS_EXPLICIT_TEST_TARGET_TRIPLE TRUE)
+if(NOT COMPILER_RT_DEFAULT_TARGET_TRIPLE STREQUAL TARGET_TRIPLE)
+  set(COMPILER_RT_HAS_EXPLICIT_DEFAULT_TARGET_TRIPLE TRUE)
 else()
-  set(COMPILER_RT_HAS_EXPLICIT_TEST_TARGET_TRIPLE FALSE)
+  set(COMPILER_RT_HAS_EXPLICIT_DEFAULT_TARGET_TRIPLE FALSE)
 endif()
 
-if ("${COMPILER_RT_TEST_TARGET_ABI}" STREQUAL "androideabi")
+if ("${COMPILER_RT_DEFAULT_TARGET_ABI}" STREQUAL "androideabi")
   set(ANDROID 1)
 endif()
 
@@ -179,6 +189,8 @@ else()
 endif()
 
 option(COMPILER_RT_DEBUG "Build runtimes with full debug info" OFF)
+option(COMPILER_RT_EXTERNALIZE_DEBUGINFO
+  "Generate dSYM files and strip executables and libraries (Darwin Only)" OFF)
 # COMPILER_RT_DEBUG_PYBOOL is used by lit.common.configured.in.
 pythonize_bool(COMPILER_RT_DEBUG)
 
@@ -216,6 +228,7 @@ append_list_if(COMPILER_RT_HAS_FUNWIND_T
 append_list_if(COMPILER_RT_HAS_FNO_STACK_PROTECTOR_FLAG -fno-stack-protector SANITIZER_COMMON_CFLAGS)
 append_list_if(COMPILER_RT_HAS_FNO_SANITIZE_SAFE_STACK_FLAG -fno-sanitize=safe-stack SANITIZER_COMMON_CFLAGS)
 append_list_if(COMPILER_RT_HAS_FVISIBILITY_HIDDEN_FLAG -fvisibility=hidden SANITIZER_COMMON_CFLAGS)
+append_list_if(COMPILER_RT_HAS_FVISIBILITY_INLINES_HIDDEN_FLAG -fvisibility-inlines-hidden SANITIZER_COMMON_CFLAGS)
 append_list_if(COMPILER_RT_HAS_FNO_FUNCTION_SECTIONS_FLAG -fno-function-sections SANITIZER_COMMON_CFLAGS)
 append_list_if(COMPILER_RT_HAS_FNO_LTO_FLAG -fno-lto SANITIZER_COMMON_CFLAGS)
 
@@ -250,8 +263,7 @@ endif()
 # FIXME: Fix all sanitizers and add -Wframe-larger-than to
 # SANITIZER_COMMON_FLAGS
 if(COMPILER_RT_HAS_WFRAME_LARGER_THAN_FLAG AND NOT COMPILER_RT_DEBUG
-   AND NOT ${LLVM_NATIVE_ARCH} STREQUAL "PowerPC"
-   AND NOT ${LLVM_NATIVE_ARCH} STREQUAL "Mips")
+   AND NOT ${COMPILER_RT_DEFAULT_TARGET_ARCH} MATCHES "powerpc|mips")
   set(SANITIZER_LIMIT_FRAME_SIZE TRUE)
 else()
   set(SANITIZER_LIMIT_FRAME_SIZE FALSE)
@@ -276,64 +288,6 @@ append_list_if(COMPILER_RT_HAS_WD4291_FL
 append_list_if(COMPILER_RT_HAS_WD4391_FLAG /wd4391 SANITIZER_COMMON_CFLAGS)
 append_list_if(COMPILER_RT_HAS_WD4722_FLAG /wd4722 SANITIZER_COMMON_CFLAGS)
 append_list_if(COMPILER_RT_HAS_WD4800_FLAG /wd4800 SANITIZER_COMMON_CFLAGS)
-if(APPLE)
-  macro(find_darwin_sdk_dir var sdk_name)
-    # Let's first try the internal SDK, otherwise use the public SDK.
-    execute_process(
-      COMMAND xcodebuild -version -sdk ${sdk_name}.internal Path
-      OUTPUT_VARIABLE ${var}
-      OUTPUT_STRIP_TRAILING_WHITESPACE
-      ERROR_FILE /dev/null
-    )
-    if(${var} STREQUAL "")
-      execute_process(
-        COMMAND xcodebuild -version -sdk ${sdk_name} Path
-        OUTPUT_VARIABLE ${var}
-        OUTPUT_STRIP_TRAILING_WHITESPACE
-        ERROR_FILE /dev/null
-      )
-    endif()
-  endmacro()
-
-  find_darwin_sdk_dir(OSX_SDK_DIR macosx)
-  find_darwin_sdk_dir(IOSSIM_SDK_DIR iphonesimulator)
-
-  set(SANITIZER_COMMON_SUPPORTED_OS osx)
-  string(REGEX MATCH "-mmacosx-version-min=([.0-9]+)"
-         MACOSX_VERSION_MIN_FLAG "${CMAKE_CXX_FLAGS}")
-  if(MACOSX_VERSION_MIN_FLAG)
-    set(SANITIZER_MIN_OSX_VERSION "${CMAKE_MATCH_1}")
-  elseif(CMAKE_OSX_DEPLOYMENT_TARGET)
-    set(SANITIZER_MIN_OSX_VERSION ${CMAKE_OSX_DEPLOYMENT_TARGET})
-  else()
-    set(SANITIZER_MIN_OSX_VERSION 10.9)
-    if(IOSSIM_SDK_DIR)
-      list(APPEND SANITIZER_COMMON_SUPPORTED_OS iossim)
-    endif()
-  endif()
-  if(SANITIZER_MIN_OSX_VERSION VERSION_LESS "10.7")
-    message(FATAL_ERROR "Too old OS X version: ${SANITIZER_MIN_OSX_VERSION}")
-  endif()
-
-  set(CMAKE_OSX_DEPLOYMENT_TARGET "") # We evaluate target OS X version above.
-  set(DARWIN_osx_CFLAGS -mmacosx-version-min=${SANITIZER_MIN_OSX_VERSION}
-    -stdlib=libc++)
-  set(DARWIN_iossim_CFLAGS
-    -stdlib=libc++
-    -mios-simulator-version-min=7.0 -isysroot ${IOSSIM_SDK_DIR})
-  set(DARWIN_osx_LINKFLAGS -mmacosx-version-min=${SANITIZER_MIN_OSX_VERSION}
-    -stdlib=libc++ -lc++ -lc++abi)
-  set(DARWIN_iossim_LINKFLAGS
-    -stdlib=libc++ -lc++ -lc++abi
-    -Wl,-ios_simulator_version_min,7.0.0
-    -mios-simulator-version-min=7.0
-    -isysroot ${IOSSIM_SDK_DIR})
-
-  if(OSX_SDK_DIR)
-    list(APPEND DARWIN_osx_CFLAGS -isysroot ${OSX_SDK_DIR})
-    list(APPEND DARWIN_osx_LINKFLAGS -isysroot ${OSX_SDK_DIR})
-  endif()
-endif()
 
 if(APPLE AND SANITIZER_MIN_OSX_VERSION VERSION_LESS "10.9")
   # Mac OS X prior to 10.9 had problems with exporting symbols from
@@ -353,9 +307,17 @@ else()
   set(COMPILER_RT_HAS_LIBCXX_SOURCES FALSE)
 endif()
 
+set(COMPILER_RT_LLD_PATH ${LLVM_MAIN_SRC_DIR}/tools/lld)
+if(EXISTS ${COMPILER_RT_LLD_PATH}/)
+  set(COMPILER_RT_HAS_LLD_SOURCES TRUE)
+else()
+  set(COMPILER_RT_HAS_LLD_SOURCES FALSE)
+endif()
+pythonize_bool(COMPILER_RT_HAS_LLD_SOURCES)
+
 add_subdirectory(lib)
 
 if(COMPILER_RT_INCLUDE_TESTS)
   add_subdirectory(unittests)
+  add_subdirectory(test)
 endif()
-add_subdirectory(test)

Modified: vendor/compiler-rt/dist/cmake/Modules/AddCompilerRT.cmake
==============================================================================
--- vendor/compiler-rt/dist/cmake/Modules/AddCompilerRT.cmake	Wed Dec 30 11:51:35 2015	(r292924)
+++ vendor/compiler-rt/dist/cmake/Modules/AddCompilerRT.cmake	Wed Dec 30 11:52:19 2015	(r292925)
@@ -19,6 +19,7 @@ function(add_compiler_rt_object_librarie
       set(libname "${name}.${os}")
       set(libnames ${libnames} ${libname})
       set(extra_cflags_${libname} ${DARWIN_${os}_CFLAGS})
+      list_union(LIB_ARCHS_${libname} DARWIN_${os}_ARCHS LIB_ARCHS)
     endforeach()
   else()
     foreach(arch ${LIB_ARCHS})
@@ -26,7 +27,7 @@ function(add_compiler_rt_object_librarie
       set(libnames ${libnames} ${libname})
       set(extra_cflags_${libname} ${TARGET_${arch}_CFLAGS})
       if(NOT CAN_TARGET_${arch})
-        message(FATAL_ERROR "Archtecture ${arch} can't be targeted")
+        message(FATAL_ERROR "Architecture ${arch} can't be targeted")
         return()
       endif()
     endforeach()
@@ -39,91 +40,130 @@ function(add_compiler_rt_object_librarie
     set_property(TARGET ${libname} APPEND PROPERTY
       COMPILE_DEFINITIONS ${LIB_DEFS})
     if(APPLE)
-      set_target_properties(${libname} PROPERTIES OSX_ARCHITECTURES "${LIB_ARCHS}")
+      set_target_properties(${libname} PROPERTIES
+        OSX_ARCHITECTURES "${LIB_ARCHS_${libname}}")
     endif()
   endforeach()
 endfunction()
 
-# Adds static or shared runtime for a given architecture and puts it in the
-# proper directory in the build and install trees.
-# add_compiler_rt_runtime(<name> <arch> {STATIC,SHARED}
+# Takes a list of object library targets, and a suffix and appends the proper
+# TARGET_OBJECTS string to the output variable.
+# format_object_libs(<output> <suffix> ...)
+macro(format_object_libs output suffix)
+  foreach(lib ${ARGN})
+    list(APPEND ${output} $<TARGET_OBJECTS:${lib}.${suffix}>)
+  endforeach()
+endmacro()
+
+# Adds static or shared runtime for a list of architectures and operating
+# systems and puts it in the proper directory in the build and install trees.
+# add_compiler_rt_runtime(<name>
+#                         {STATIC|SHARED}
+#                         ARCHS <architectures>
+#                         OS <os list>
 #                         SOURCES <source files>
 #                         CFLAGS <compile flags>
+#                         LINKFLAGS <linker flags>
 #                         DEFS <compile definitions>
-#                         OUTPUT_NAME <output library name>)
-macro(add_compiler_rt_runtime name arch type)
-  if(CAN_TARGET_${arch})
-    cmake_parse_arguments(LIB "" "OUTPUT_NAME" "SOURCES;CFLAGS;LINKFLAGS;DEFS" ${ARGN})
-    add_library(${name} ${type} ${LIB_SOURCES})
-    # Setup compile flags and definitions.
-    set_target_compile_flags(${name}
-      ${TARGET_${arch}_CFLAGS} ${LIB_CFLAGS})
-    set_target_link_flags(${name}
-      ${TARGET_${arch}_CFLAGS} ${LIB_CFLAGS} ${LIB_LINKFLAGS})
-    set_property(TARGET ${name} APPEND PROPERTY
-      COMPILE_DEFINITIONS ${LIB_DEFS})
-    # Setup correct output directory in the build tree.
-    set_target_properties(${name} PROPERTIES
-      ARCHIVE_OUTPUT_DIRECTORY ${COMPILER_RT_LIBRARY_OUTPUT_DIR}
-      LIBRARY_OUTPUT_DIRECTORY ${COMPILER_RT_LIBRARY_OUTPUT_DIR}
-      RUNTIME_OUTPUT_DIRECTORY ${COMPILER_RT_LIBRARY_OUTPUT_DIR})
-    if ("${LIB_OUTPUT_NAME}" STREQUAL "")
-      set_target_properties(${name} PROPERTIES
-        OUTPUT_NAME ${name}${COMPILER_RT_OS_SUFFIX})
-    else()
-      set_target_properties(${name} PROPERTIES
-        OUTPUT_NAME ${LIB_OUTPUT_NAME})
-    endif()
-    # Add installation command.
-    install(TARGETS ${name}
-      ARCHIVE DESTINATION ${COMPILER_RT_LIBRARY_INSTALL_DIR}
-      LIBRARY DESTINATION ${COMPILER_RT_LIBRARY_INSTALL_DIR}
-      RUNTIME DESTINATION ${COMPILER_RT_LIBRARY_INSTALL_DIR})
+#                         LINK_LIBS <linked libraries> (only for shared library)
+#                         OBJECT_LIBS <object libraries to use as sources>
+#                         PARENT_TARGET <convenience parent target>)
+function(add_compiler_rt_runtime name type)
+  if(NOT type MATCHES "^(STATIC|SHARED)$")
+    message(FATAL_ERROR "type argument must be STATIC or SHARED")
+    return()
+  endif()
+  cmake_parse_arguments(LIB
+    ""
+    "PARENT_TARGET"
+    "OS;ARCHS;SOURCES;CFLAGS;LINKFLAGS;DEFS;LINK_LIBS;OBJECT_LIBS"
+    ${ARGN})
+  set(libnames)
+  if(APPLE)
+    foreach(os ${LIB_OS})
+      if(type STREQUAL "STATIC")
+        set(libname "${name}_${os}")
+      else()
+        set(libname "${name}_${os}_dynamic")
+        set(extra_linkflags_${libname} ${DARWIN_${os}_LINKFLAGS} ${LIB_LINKFLAGS})
+      endif()
+      list_union(LIB_ARCHS_${libname} DARWIN_${os}_ARCHS LIB_ARCHS)
+      if(LIB_ARCHS_${libname})
+        list(APPEND libnames ${libname})
+        set(extra_cflags_${libname} ${DARWIN_${os}_CFLAGS} ${LIB_CFLAGS})
+        set(output_name_${libname} ${libname}${COMPILER_RT_OS_SUFFIX})
+        set(sources_${libname} ${LIB_SOURCES})
+        format_object_libs(sources_${libname} ${os} ${LIB_OBJECT_LIBS})
+      endif()
+    endforeach()
   else()
-    message(FATAL_ERROR "Archtecture ${arch} can't be targeted")
+    foreach(arch ${LIB_ARCHS})
+      if(NOT CAN_TARGET_${arch})
+        message(FATAL_ERROR "Architecture ${arch} can't be targeted")
+        return()
+      endif()
+      if(type STREQUAL "STATIC")
+        set(libname "${name}-${arch}")
+        set(output_name_${libname} ${libname}${COMPILER_RT_OS_SUFFIX})
+      else()
+        set(libname "${name}-dynamic-${arch}")
+        set(extra_linkflags_${libname} ${TARGET_${arch}_CFLAGS} ${LIB_CFLAGS} ${LIB_LINKFLAGS})
+        if(WIN32)
+          set(output_name_${libname} ${name}_dynamic-${arch}${COMPILER_RT_OS_SUFFIX})
+        else()
+          set(output_name_${libname} ${name}-${arch}${COMPILER_RT_OS_SUFFIX})
+        endif()
+      endif()
+      set(sources_${libname} ${LIB_SOURCES})
+      format_object_libs(sources_${libname} ${arch} ${LIB_OBJECT_LIBS})
+      set(libnames ${libnames} ${libname})
+      set(extra_cflags_${libname} ${TARGET_${arch}_CFLAGS} ${LIB_CFLAGS})
+    endforeach()
   endif()
-endmacro()
 
-# Same as add_compiler_rt_runtime(... STATIC), but creates a universal library
-# for several architectures.
-# add_compiler_rt_osx_static_runtime(<name> ARCHS <architectures>
-#                                    SOURCES <source files>
-#                                    CFLAGS <compile flags>
-#                                    DEFS <compile definitions>)
-macro(add_compiler_rt_osx_static_runtime name)
-  cmake_parse_arguments(LIB "" "" "ARCHS;SOURCES;CFLAGS;DEFS" ${ARGN})
-  add_library(${name} STATIC ${LIB_SOURCES})
-  set_target_compile_flags(${name} ${LIB_CFLAGS})
-  set_property(TARGET ${name} APPEND PROPERTY
-    COMPILE_DEFINITIONS ${LIB_DEFS})
-  set_target_properties(${name} PROPERTIES
-    OSX_ARCHITECTURES "${LIB_ARCHS}"
-    ARCHIVE_OUTPUT_DIRECTORY ${COMPILER_RT_LIBRARY_OUTPUT_DIR})
-  install(TARGETS ${name}
-    ARCHIVE DESTINATION ${COMPILER_RT_LIBRARY_INSTALL_DIR})
-endmacro()
+  if(NOT libnames)
+    return()
+  endif()
 
-# Adds dynamic runtime library on osx/iossim, which supports multiple
-# architectures.
-# add_compiler_rt_darwin_dynamic_runtime(<name> <os>
-#                                        ARCHS <architectures>
-#                                        SOURCES <source files>
-#                                        CFLAGS <compile flags>
-#                                        DEFS <compile definitions>
-#                                        LINKFLAGS <link flags>)
-macro(add_compiler_rt_darwin_dynamic_runtime name os)
-  cmake_parse_arguments(LIB "" "" "ARCHS;SOURCES;CFLAGS;DEFS;LINKFLAGS" ${ARGN})
-  add_library(${name} SHARED ${LIB_SOURCES})
-  set_target_compile_flags(${name} ${LIB_CFLAGS} ${DARWIN_${os}_CFLAGS})
-  set_target_link_flags(${name} ${LIB_LINKFLAGS} ${DARWIN_${os}_LINKFLAGS})
-  set_property(TARGET ${name} APPEND PROPERTY
-    COMPILE_DEFINITIONS ${LIB_DEFS})
-  set_target_properties(${name} PROPERTIES
-    OSX_ARCHITECTURES "${LIB_ARCHS}"
-    LIBRARY_OUTPUT_DIRECTORY ${COMPILER_RT_LIBRARY_OUTPUT_DIR})
-  install(TARGETS ${name}
-    LIBRARY DESTINATION ${COMPILER_RT_LIBRARY_INSTALL_DIR})
-endmacro()
+  if(LIB_PARENT_TARGET)
+    set(COMPONENT_OPTION COMPONENT ${LIB_PARENT_TARGET})
+  endif()
+
+  foreach(libname ${libnames})
+    add_library(${libname} ${type} ${sources_${libname}})
+    set_target_compile_flags(${libname} ${extra_cflags_${libname}})
+    set_target_link_flags(${libname} ${extra_linkflags_${libname}})
+    set_property(TARGET ${libname} APPEND PROPERTY 
+                COMPILE_DEFINITIONS ${LIB_DEFS})
+    set_target_properties(${libname} PROPERTIES
+        ARCHIVE_OUTPUT_DIRECTORY ${COMPILER_RT_LIBRARY_OUTPUT_DIR}
+        LIBRARY_OUTPUT_DIRECTORY ${COMPILER_RT_LIBRARY_OUTPUT_DIR}
+        RUNTIME_OUTPUT_DIRECTORY ${COMPILER_RT_LIBRARY_OUTPUT_DIR})
+    set_target_properties(${libname} PROPERTIES
+        OUTPUT_NAME ${output_name_${libname}})
+    if(LIB_LINK_LIBS AND ${type} STREQUAL "SHARED")
+      target_link_libraries(${libname} ${LIB_LINK_LIBS})
+    endif()
+    install(TARGETS ${libname}
+      ARCHIVE DESTINATION ${COMPILER_RT_LIBRARY_INSTALL_DIR}
+              ${COMPONENT_OPTION}
+      LIBRARY DESTINATION ${COMPILER_RT_LIBRARY_INSTALL_DIR}
+              ${COMPONENT_OPTION}
+      RUNTIME DESTINATION ${COMPILER_RT_LIBRARY_INSTALL_DIR}
+              ${COMPONENT_OPTION})
+    if(APPLE)
+      set_target_properties(${libname} PROPERTIES
+      OSX_ARCHITECTURES "${LIB_ARCHS_${libname}}")
+    endif()
+
+    if(type STREQUAL "SHARED")
+      rt_externalize_debuginfo(${libname})
+    endif()
+  endforeach()
+  if(LIB_PARENT_TARGET)
+    add_dependencies(${LIB_PARENT_TARGET} ${libnames})
+  endif()
+endfunction()
 
 set(COMPILER_RT_TEST_CFLAGS)
 
@@ -248,7 +288,8 @@ macro(add_custom_libcxx name prefix)
   ExternalProject_Add(${name}
     PREFIX ${prefix}
     SOURCE_DIR ${COMPILER_RT_LIBCXX_PATH}
-    CMAKE_ARGS -DCMAKE_C_COMPILER=${COMPILER_RT_TEST_COMPILER}
+    CMAKE_ARGS -DCMAKE_MAKE_PROGRAM:STRING=${CMAKE_MAKE_PROGRAM}
+               -DCMAKE_C_COMPILER=${COMPILER_RT_TEST_COMPILER}
                -DCMAKE_CXX_COMPILER=${COMPILER_RT_TEST_COMPILER}
                -DCMAKE_C_FLAGS=${LIBCXX_CFLAGS}
                -DCMAKE_CXX_FLAGS=${LIBCXX_CFLAGS}
@@ -273,3 +314,24 @@ macro(add_custom_libcxx name prefix)
     DEPENDS ${LIBCXX_DEPS}
     )
 endmacro()
+
+function(rt_externalize_debuginfo name)
+  if(NOT COMPILER_RT_EXTERNALIZE_DEBUGINFO)
+    return()
+  endif()
+
+  if(APPLE)
+    if(CMAKE_CXX_FLAGS MATCHES "-flto"
+      OR CMAKE_CXX_FLAGS_${uppercase_CMAKE_BUILD_TYPE} MATCHES "-flto")
+
+      set(lto_object ${CMAKE_CURRENT_BINARY_DIR}/${CMAKE_CFG_INTDIR}/${name}-lto.o)
+      set_property(TARGET ${name} APPEND_STRING PROPERTY
+        LINK_FLAGS " -Wl,-object_path_lto -Wl,${lto_object}")
+    endif()
+    add_custom_command(TARGET ${name} POST_BUILD
+      COMMAND xcrun dsymutil $<TARGET_FILE:${name}>
+      COMMAND xcrun strip -Sl $<TARGET_FILE:${name}>)
+  else()
+    message(FATAL_ERROR "COMPILER_RT_EXTERNALIZE_DEBUGINFO isn't implemented for non-darwin platforms!")
+  endif()
+endfunction()

Modified: vendor/compiler-rt/dist/cmake/Modules/CompilerRTCompile.cmake
==============================================================================
--- vendor/compiler-rt/dist/cmake/Modules/CompilerRTCompile.cmake	Wed Dec 30 11:51:35 2015	(r292924)
+++ vendor/compiler-rt/dist/cmake/Modules/CompilerRTCompile.cmake	Wed Dec 30 11:52:19 2015	(r292925)
@@ -49,6 +49,10 @@ macro(clang_compile object_file source)
     translate_msvc_cflags(global_flags "${global_flags}")
   endif()
 
+  if (APPLE)
+    set(global_flags ${OSX_SYSROOT_FLAG} ${global_flags})
+  endif()
+
   # Ignore unknown warnings. CMAKE_CXX_FLAGS may contain GCC-specific options
   # which are not supported by Clang.
   list(APPEND global_flags -Wno-unknown-warning-option)
@@ -72,7 +76,7 @@ endmacro()
 macro(clang_compiler_add_cxx_check)
   if (APPLE)
     set(CMD
-      "echo '#include <iostream>' | ${COMPILER_RT_TEST_COMPILER} -E -x c++ - > /dev/null"
+      "echo '#include <iostream>' | ${COMPILER_RT_TEST_COMPILER} ${OSX_SYSROOT_FLAG} -E -x c++ - > /dev/null"
       "if [ $? != 0 ] "
       "  then echo"
       "  echo 'Your just-built clang cannot find C++ headers, which are needed to build and run compiler-rt tests.'"

Added: vendor/compiler-rt/dist/cmake/Modules/CompilerRTDarwinUtils.cmake
==============================================================================
--- /dev/null	00:00:00 1970	(empty, because file is newly added)
+++ vendor/compiler-rt/dist/cmake/Modules/CompilerRTDarwinUtils.cmake	Wed Dec 30 11:52:19 2015	(r292925)
@@ -0,0 +1,453 @@
+# On OS X SDKs can be installed anywhere on the base system and xcode-select can
+# set the default Xcode to use. This function finds the SDKs that are present in
+# the current Xcode.
+function(find_darwin_sdk_dir var sdk_name)
+  # Let's first try the internal SDK, otherwise use the public SDK.
+  execute_process(
+    COMMAND xcodebuild -version -sdk ${sdk_name}.internal Path
+    OUTPUT_VARIABLE var_internal
+    OUTPUT_STRIP_TRAILING_WHITESPACE
+    ERROR_FILE /dev/null
+  )
+  if("" STREQUAL "${var_internal}")
+    execute_process(
+      COMMAND xcodebuild -version -sdk ${sdk_name} Path
+      OUTPUT_VARIABLE var_internal
+      OUTPUT_STRIP_TRAILING_WHITESPACE
+      ERROR_FILE /dev/null
+    )
+  endif()
+  set(${var} ${var_internal} PARENT_SCOPE)
+endfunction()
+
+# There isn't a clear mapping of what architectures are supported with a given
+# target platform, but ld's version output does list the architectures it can
+# link for.
+function(darwin_get_toolchain_supported_archs output_var)
+  execute_process(
+    COMMAND ld -v
+    ERROR_VARIABLE LINKER_VERSION)
+
+  string(REGEX MATCH "configured to support archs: ([^\n]+)"
+         ARCHES_MATCHED "${LINKER_VERSION}")
+  if(ARCHES_MATCHED)
+    set(ARCHES "${CMAKE_MATCH_1}")
+    message(STATUS "Got ld supported ARCHES: ${ARCHES}")
+    string(REPLACE " " ";" ARCHES ${ARCHES})
+  else()
+    # If auto-detecting fails, fall back to a default set
+    message(WARNING "Detecting supported architectures from 'ld -v' failed. Returning default set.")
+    set(ARCHES "i386;x86_64;armv7;armv7s;arm64")
+  endif()
+  
+  set(${output_var} ${ARCHES} PARENT_SCOPE)
+endfunction()
+
+# This function takes an OS and a list of architectures and identifies the
+# subset of the architectures list that the installed toolchain can target.
+function(darwin_test_archs os valid_archs)
+  if(${valid_archs})
+    message(STATUS "Using cached valid architectures for ${os}.")
+    return()
+  endif()
+
+  set(archs ${ARGN})
+  message(STATUS "Finding valid architectures for ${os}...")
+  set(SIMPLE_CPP ${CMAKE_BINARY_DIR}${CMAKE_FILES_DIRECTORY}/src.cpp)
+  file(WRITE ${SIMPLE_CPP} "#include <iostream>\nint main() { std::cout << std::endl; return 0; }\n")
+
+  set(os_linker_flags)
+  foreach(flag ${DARWIN_${os}_LINKFLAGS})
+    set(os_linker_flags "${os_linker_flags} ${flag}")
+  endforeach()
+
+  # The simple program will build for x86_64h on the simulator because it is 
+  # compatible with x86_64 libraries (mostly), but since x86_64h isn't actually
+  # a valid or useful architecture for the iOS simulator we should drop it.
+  if(${os} STREQUAL "iossim")
+    list(REMOVE_ITEM archs "x86_64h")
+  endif()
+
+  set(working_archs)
+  foreach(arch ${archs})
+    
+    set(arch_linker_flags "-arch ${arch} ${os_linker_flags}")
+    try_compile(CAN_TARGET_${os}_${arch} ${CMAKE_BINARY_DIR} ${SIMPLE_CPP}
+                COMPILE_DEFINITIONS "-v -arch ${arch}" ${DARWIN_${os}_CFLAGS}
+                CMAKE_FLAGS "-DCMAKE_EXE_LINKER_FLAGS=${arch_linker_flags}"
+                OUTPUT_VARIABLE TEST_OUTPUT)
+    if(${CAN_TARGET_${os}_${arch}})
+      list(APPEND working_archs ${arch})
+    else()
+      file(APPEND ${CMAKE_BINARY_DIR}${CMAKE_FILES_DIRECTORY}/CMakeError.log
+        "Testing compiler for supporting ${os}-${arch}:\n"
+        "${TEST_OUTPUT}\n")
+    endif()
+  endforeach()
+  set(${valid_archs} ${working_archs}
+    CACHE STRING "List of valid architectures for platform ${os}.")
+endfunction()
+
+# This function checks the host cpusubtype to see if it is post-haswell. Haswell
+# and later machines can run x86_64h binaries. Haswell is cpusubtype 8.
+function(darwin_filter_host_archs input output)
+  list_union(tmp_var DARWIN_osx_ARCHS ${input})
+  execute_process(
+    COMMAND sysctl hw.cpusubtype
+    OUTPUT_VARIABLE SUBTYPE)
+
+  string(REGEX MATCH "hw.cpusubtype: ([0-9]*)"
+         SUBTYPE_MATCHED "${SUBTYPE}")
+  set(HASWELL_SUPPORTED Off)
+  if(SUBTYPE_MATCHED)
+    if(${CMAKE_MATCH_1} GREATER 7)
+      set(HASWELL_SUPPORTED On)
+    endif()
+  endif()
+  if(NOT HASWELL_SUPPORTED)
+    list(REMOVE_ITEM tmp_var x86_64h)
+  endif()
+  set(${output} ${tmp_var} PARENT_SCOPE)
+endfunction()
+
+# Read and process the exclude file into a list of symbols
+function(darwin_read_list_from_file output_var file)
+  if(EXISTS ${file})
+    file(READ ${file} EXCLUDES)
+    string(REPLACE "\n" ";" EXCLUDES ${EXCLUDES})
+    set(${output_var} ${EXCLUDES} PARENT_SCOPE)
+  endif()
+endfunction()
+
+# this function takes an OS, architecture and minimum version and provides a
+# list of builtin functions to exclude
+function(darwin_find_excluded_builtins_list output_var)
+  cmake_parse_arguments(LIB
+    ""
+    "OS;ARCH;MIN_VERSION"
+    ""
+    ${ARGN})
+
+  if(NOT LIB_OS OR NOT LIB_ARCH)
+    message(FATAL_ERROR "Must specify OS and ARCH to darwin_find_excluded_builtins_list!")
+  endif()
+
+  darwin_read_list_from_file(${LIB_OS}_BUILTINS
+    ${DARWIN_EXCLUDE_DIR}/${LIB_OS}.txt)
+  darwin_read_list_from_file(${LIB_OS}_${LIB_ARCH}_BASE_BUILTINS
+    ${DARWIN_EXCLUDE_DIR}/${LIB_OS}-${LIB_ARCH}.txt)
+
+  if(LIB_MIN_VERSION)
+    file(GLOB builtin_lists ${DARWIN_EXCLUDE_DIR}/${LIB_OS}*-${LIB_ARCH}.txt)
+    foreach(builtin_list ${builtin_lists})
+      string(REGEX MATCH "${LIB_OS}([0-9\\.]*)-${LIB_ARCH}.txt" VERSION_MATCHED "${builtin_list}")
+      if (VERSION_MATCHED AND NOT CMAKE_MATCH_1 VERSION_LESS LIB_MIN_VERSION)
+        if(NOT smallest_version)
+          set(smallest_version ${CMAKE_MATCH_1})
+        elseif(CMAKE_MATCH_1 VERSION_LESS smallest_version)
+          set(smallest_version ${CMAKE_MATCH_1})
+        endif()
+      endif()
+    endforeach()
+
+    if(smallest_version)
+      darwin_read_list_from_file(${LIB_ARCH}_${LIB_OS}_BUILTINS
+        ${DARWIN_EXCLUDE_DIR}/${LIB_OS}${smallest_version}-${LIB_ARCH}.txt)
+    endif()
+  endif()
+  
+  set(${output_var}
+      ${${LIB_ARCH}_${LIB_OS}_BUILTINS}
+      ${${LIB_OS}_${LIB_ARCH}_BASE_BUILTINS}
+      ${${LIB_OS}_BUILTINS} PARENT_SCOPE)
+endfunction()
+
+# adds a single builtin library for a single OS & ARCH
+macro(darwin_add_builtin_library name suffix)
+  cmake_parse_arguments(LIB
+    ""
+    "PARENT_TARGET;OS;ARCH"
+    "SOURCES;CFLAGS;DEFS"
+    ${ARGN})
+  set(libname "${name}.${suffix}_${LIB_ARCH}_${LIB_OS}")
+  add_library(${libname} STATIC ${LIB_SOURCES})
+  if(DARWIN_${LIB_OS}_SYSROOT)
+    set(sysroot_flag -isysroot ${DARWIN_${LIB_OS}_SYSROOT})
+  endif()
+  set_target_compile_flags(${libname}
+    ${sysroot_flag}
+    ${DARWIN_${LIB_OS}_BUILTIN_MIN_VER_FLAG}
+    ${LIB_CFLAGS})
+  set_property(TARGET ${libname} APPEND PROPERTY
+      COMPILE_DEFINITIONS ${LIB_DEFS})
+  set_target_properties(${libname} PROPERTIES
+      OUTPUT_NAME ${libname}${COMPILER_RT_OS_SUFFIX})
+  set_target_properties(${libname} PROPERTIES
+    OSX_ARCHITECTURES ${LIB_ARCH})
+
+  if(LIB_PARENT_TARGET)
+    add_dependencies(${LIB_PARENT_TARGET} ${libname})
+  endif()
+
+  list(APPEND ${LIB_OS}_${suffix}_libs ${libname})
+  list(APPEND ${LIB_OS}_${suffix}_lipo_flags -arch ${arch} $<TARGET_FILE:${libname}>)
+endmacro()
+
+function(darwin_lipo_libs name)
+  cmake_parse_arguments(LIB
+    ""
+    "PARENT_TARGET;OUTPUT_DIR;INSTALL_DIR"
+    "LIPO_FLAGS;DEPENDS"
+    ${ARGN})
+  if(LIB_DEPENDS AND LIB_LIPO_FLAGS)
+    add_custom_command(OUTPUT ${LIB_OUTPUT_DIR}/lib${name}.a
+      COMMAND ${CMAKE_COMMAND} -E make_directory ${LIB_OUTPUT_DIR}
+      COMMAND lipo -output
+              ${LIB_OUTPUT_DIR}/lib${name}.a
+              -create ${LIB_LIPO_FLAGS}
+      DEPENDS ${LIB_DEPENDS}
+      )
+    add_custom_target(${name}
+      DEPENDS ${LIB_OUTPUT_DIR}/lib${name}.a)
+    add_dependencies(${LIB_PARENT_TARGET} ${name})
+    install(FILES ${LIB_OUTPUT_DIR}/lib${name}.a
+      DESTINATION ${LIB_INSTALL_DIR})
+  else()
+    message(WARNING "Not generating lipo target for ${name} because no input libraries exist.")
+  endif()
+endfunction()
+
+# Filter out generic versions of routines that are re-implemented in
+# architecture specific manner.  This prevents multiple definitions of the
+# same symbols, making the symbol selection non-deterministic.
+function(darwin_filter_builtin_sources output_var exclude_or_include excluded_list)
+  if(exclude_or_include STREQUAL "EXCLUDE")
+    set(filter_action GREATER)
+    set(filter_value -1)
+  elseif(exclude_or_include STREQUAL "INCLUDE")
+    set(filter_action LESS)
+    set(filter_value 0)
+  else()
+    message(FATAL_ERROR "darwin_filter_builtin_sources called without EXCLUDE|INCLUDE")
+  endif()
+
+  set(intermediate ${ARGN})
+  foreach (_file ${intermediate})
+    get_filename_component(_name_we ${_file} NAME_WE)
+    list(FIND ${excluded_list} ${_name_we} _found)
+    if(_found ${filter_action} ${filter_value})
+      list(REMOVE_ITEM intermediate ${_file})
+    elseif(${_file} MATCHES ".*/.*\\.S" OR ${_file} MATCHES ".*/.*\\.c")
+      get_filename_component(_name ${_file} NAME)
+      string(REPLACE ".S" ".c" _cname "${_name}")
+      list(REMOVE_ITEM intermediate ${_cname})
+    endif ()
+  endforeach ()
+  set(${output_var} ${intermediate} PARENT_SCOPE)
+endfunction()
+
+function(darwin_add_eprintf_library)
+  cmake_parse_arguments(LIB
+    ""
+    ""
+    "CFLAGS"
+    ${ARGN})
+
+  add_library(clang_rt.eprintf STATIC eprintf.c)
+  set_target_compile_flags(clang_rt.eprintf
+    -isysroot ${DARWIN_osx_SYSROOT}
+    ${DARWIN_osx_BUILTIN_MIN_VER_FLAG}
+    -arch i386
+    ${LIB_CFLAGS})
+  set_target_properties(clang_rt.eprintf PROPERTIES
+      OUTPUT_NAME clang_rt.eprintf${COMPILER_RT_OS_SUFFIX})
+  set_target_properties(clang_rt.eprintf PROPERTIES
+    OSX_ARCHITECTURES i386)
+  add_dependencies(builtins clang_rt.eprintf)
+  set_target_properties(clang_rt.eprintf PROPERTIES
+        ARCHIVE_OUTPUT_DIRECTORY ${COMPILER_RT_LIBRARY_OUTPUT_DIR})
+  install(TARGETS clang_rt.eprintf
+      ARCHIVE DESTINATION ${COMPILER_RT_LIBRARY_INSTALL_DIR})
+endfunction()
+
+# Generates builtin libraries for all operating systems specified in ARGN. Each
+# OS library is constructed by lipo-ing together single-architecture libraries.
+macro(darwin_add_builtin_libraries)
+  set(DARWIN_EXCLUDE_DIR ${CMAKE_CURRENT_SOURCE_DIR}/Darwin-excludes)
+
+  set(CFLAGS "-fPIC -O3 -fvisibility=hidden -DVISIBILITY_HIDDEN -Wall -fomit-frame-pointer")
+  set(CMAKE_C_FLAGS "")
+  set(CMAKE_CXX_FLAGS "")
+  set(CMAKE_ASM_FLAGS "")
+
+  set(PROFILE_SOURCES ../profile/InstrProfiling 
+                      ../profile/InstrProfilingBuffer
+                      ../profile/InstrProfilingPlatformDarwin)
+  foreach (os ${ARGN})
+    list_union(DARWIN_BUILTIN_ARCHS DARWIN_${os}_ARCHS BUILTIN_SUPPORTED_ARCH)
+    foreach (arch ${DARWIN_BUILTIN_ARCHS})
+      darwin_find_excluded_builtins_list(${arch}_${os}_EXCLUDED_BUILTINS
+                              OS ${os}
+                              ARCH ${arch}
+                              MIN_VERSION ${DARWIN_${os}_BUILTIN_MIN_VER})
+
+      darwin_filter_builtin_sources(filtered_sources
+        EXCLUDE ${arch}_${os}_EXCLUDED_BUILTINS
+        ${${arch}_SOURCES})
+
+      darwin_add_builtin_library(clang_rt builtins
+                              OS ${os}
+                              ARCH ${arch}
+                              SOURCES ${filtered_sources}
+                              CFLAGS ${CFLAGS} -arch ${arch}
+                              PARENT_TARGET builtins)
+    endforeach()
+
+    # Don't build cc_kext libraries for simulator platforms
+    if(NOT DARWIN_${os}_SKIP_CC_KEXT)
+      foreach (arch ${DARWIN_BUILTIN_ARCHS})
+        # By not specifying MIN_VERSION this only reads the OS and OS-arch lists.
+        # We don't want to filter out the builtins that are present in libSystem
+        # because kexts can't link libSystem.
+        darwin_find_excluded_builtins_list(${arch}_${os}_EXCLUDED_BUILTINS
+                              OS ${os}
+                              ARCH ${arch})
+
+        darwin_filter_builtin_sources(filtered_sources
+          EXCLUDE ${arch}_${os}_EXCLUDED_BUILTINS
+          ${${arch}_SOURCES})
+
+        # In addition to the builtins cc_kext includes some profile sources
+        darwin_add_builtin_library(clang_rt cc_kext
+                                OS ${os}
+                                ARCH ${arch}
+                                SOURCES ${filtered_sources} ${PROFILE_SOURCES}
+                                CFLAGS ${CFLAGS} -arch ${arch} -mkernel
+                                DEFS KERNEL_USE
+                                PARENT_TARGET builtins)
+      endforeach()
+      set(archive_name clang_rt.cc_kext_${os})
+      if(${os} STREQUAL "osx")
+        set(archive_name clang_rt.cc_kext)
+      endif()
+      darwin_lipo_libs(${archive_name}
+                      PARENT_TARGET builtins
+                      LIPO_FLAGS ${${os}_cc_kext_lipo_flags}
+                      DEPENDS ${${os}_cc_kext_libs}
+                      OUTPUT_DIR ${COMPILER_RT_LIBRARY_OUTPUT_DIR}
+                      INSTALL_DIR ${COMPILER_RT_LIBRARY_INSTALL_DIR})
+    endif()
+  endforeach()
+
+  darwin_add_eprintf_library(CFLAGS ${CFLAGS})
+
+  # We put the x86 sim slices into the archives for their base OS
+  foreach (os ${ARGN})
+    if(NOT ${os} MATCHES ".*sim$")
+      darwin_lipo_libs(clang_rt.${os}
+                        PARENT_TARGET builtins
+                        LIPO_FLAGS ${${os}_builtins_lipo_flags} ${${os}sim_builtins_lipo_flags}
+                        DEPENDS ${${os}_builtins_libs} ${${os}sim_builtins_libs}
+                        OUTPUT_DIR ${COMPILER_RT_LIBRARY_OUTPUT_DIR}
+                        INSTALL_DIR ${COMPILER_RT_LIBRARY_INSTALL_DIR})
+    endif()
+  endforeach()
+  darwin_add_embedded_builtin_libraries()
+endmacro()
+
+macro(darwin_add_embedded_builtin_libraries)
+  # this is a hacky opt-out. If you can't target both intel and arm
+  # architectures we bail here.
+  set(DARWIN_SOFT_FLOAT_ARCHS armv6m armv7m armv7em armv7)
+  set(DARWIN_HARD_FLOAT_ARCHS armv7em armv7)
+  if(COMPILER_RT_SUPPORTED_ARCH MATCHES ".*armv.*")
+    list(FIND COMPILER_RT_SUPPORTED_ARCH i386 i386_idx)
+    if(i386_idx GREATER -1)
+      list(APPEND DARWIN_HARD_FLOAT_ARCHS i386)
+    endif()
+
+    list(FIND COMPILER_RT_SUPPORTED_ARCH x86_64 x86_64_idx)
+    if(x86_64_idx GREATER -1)
+      list(APPEND DARWIN_HARD_FLOAT_ARCHS x86_64)
+    endif()
+
+    set(MACHO_SYM_DIR ${CMAKE_CURRENT_SOURCE_DIR}/macho_embedded)
+
+    set(CFLAGS "-Oz -Wall -fomit-frame-pointer -ffreestanding")
+    set(CMAKE_C_FLAGS "")
+    set(CMAKE_CXX_FLAGS "")
+    set(CMAKE_ASM_FLAGS "")
+
+    set(SOFT_FLOAT_FLAG -mfloat-abi=soft)
+    set(HARD_FLOAT_FLAG -mfloat-abi=hard)
+
+    set(ENABLE_PIC Off)
+    set(PIC_FLAG -fPIC)
+    set(STATIC_FLAG -static)
+
+    set(DARWIN_macho_embedded_ARCHS armv6m armv7m armv7em armv7 i386 x86_64)
+
+    set(DARWIN_macho_embedded_LIBRARY_OUTPUT_DIR
+      ${COMPILER_RT_OUTPUT_DIR}/lib/macho_embedded)
+    set(DARWIN_macho_embedded_LIBRARY_INSTALL_DIR
+      ${COMPILER_RT_INSTALL_PATH}/lib/macho_embedded)
+      
+    set(CFLAGS_armv7 "-target thumbv7-apple-darwin-eabi")
+    set(CFLAGS_i386 "-march=pentium")
+
+    darwin_read_list_from_file(common_FUNCTIONS ${MACHO_SYM_DIR}/common.txt)
+    darwin_read_list_from_file(thumb2_FUNCTIONS ${MACHO_SYM_DIR}/thumb2.txt)
+    darwin_read_list_from_file(thumb2_64_FUNCTIONS ${MACHO_SYM_DIR}/thumb2-64.txt)
+    darwin_read_list_from_file(arm_FUNCTIONS ${MACHO_SYM_DIR}/arm.txt)
+    darwin_read_list_from_file(i386_FUNCTIONS ${MACHO_SYM_DIR}/i386.txt)
+
+
+    set(armv6m_FUNCTIONS ${common_FUNCTIONS} ${arm_FUNCTIONS})
+    set(armv7m_FUNCTIONS ${common_FUNCTIONS} ${arm_FUNCTIONS} ${thumb2_FUNCTIONS})
+    set(armv7em_FUNCTIONS ${common_FUNCTIONS} ${arm_FUNCTIONS} ${thumb2_FUNCTIONS})
+    set(armv7_FUNCTIONS ${common_FUNCTIONS} ${arm_FUNCTIONS} ${thumb2_FUNCTIONS} ${thumb2_64_FUNCTIONS})
+    set(i386_FUNCTIONS ${common_FUNCTIONS} ${i386_FUNCTIONS})
+    set(x86_64_FUNCTIONS ${common_FUNCTIONS})
+
+    foreach(arch ${DARWIN_macho_embedded_ARCHS})
+      darwin_filter_builtin_sources(${arch}_filtered_sources
+        INCLUDE ${arch}_FUNCTIONS
+        ${${arch}_SOURCES})
+      if(NOT ${arch}_filtered_sources)
+        message("${arch}_SOURCES: ${${arch}_SOURCES}")
+        message("${arch}_FUNCTIONS: ${${arch}_FUNCTIONS}")
+        message(FATAL_ERROR "Empty filtered sources!")
+      endif()
+    endforeach()
+
+    foreach(float_type SOFT HARD)
+      foreach(type PIC STATIC)
+        string(TOLOWER "${float_type}_${type}" lib_suffix)
+        foreach(arch ${DARWIN_${float_type}_FLOAT_ARCHS})
+          set(DARWIN_macho_embedded_SYSROOT ${DARWIN_osx_SYSROOT})
+          set(float_flag)
+          if(${arch} MATCHES "^arm")
+            # x86 targets are hard float by default, but the complain about the
+            # float ABI flag, so don't pass it unless we're targeting arm.
+            set(float_flag ${${float_type}_FLOAT_FLAG})
+          endif()
+          darwin_add_builtin_library(clang_rt ${lib_suffix}
+                                OS macho_embedded
+                                ARCH ${arch}
+                                SOURCES ${${arch}_filtered_sources}
+                                CFLAGS ${CFLAGS} -arch ${arch} ${${type}_FLAG} ${float_flag} ${CFLAGS_${arch}}
+                                PARENT_TARGET builtins)
+        endforeach()
+        foreach(lib ${macho_embedded_${lib_suffix}_libs})
+          set_target_properties(${lib} PROPERTIES LINKER_LANGUAGE C)
+        endforeach()
+        darwin_lipo_libs(clang_rt.${lib_suffix}
+                      PARENT_TARGET builtins
+                      LIPO_FLAGS ${macho_embedded_${lib_suffix}_lipo_flags}
+                      DEPENDS ${macho_embedded_${lib_suffix}_libs}
+                      OUTPUT_DIR ${DARWIN_macho_embedded_LIBRARY_OUTPUT_DIR}
+                      INSTALL_DIR ${DARWIN_macho_embedded_LIBRARY_INSTALL_DIR})
+      endforeach()
+    endforeach()
+  endif()
+endmacro()

Modified: vendor/compiler-rt/dist/cmake/Modules/CompilerRTUtils.cmake
==============================================================================
--- vendor/compiler-rt/dist/cmake/Modules/CompilerRTUtils.cmake	Wed Dec 30 11:51:35 2015	(r292924)
+++ vendor/compiler-rt/dist/cmake/Modules/CompilerRTUtils.cmake	Wed Dec 30 11:52:19 2015	(r292925)
@@ -57,3 +57,13 @@ macro(append_have_file_definition filena
   endif()
   list(APPEND ${list} "${varname}=${${varname}}")
 endmacro()
+
+macro(list_union output input1 input2)
+  set(${output})
+  foreach(it ${${input1}})
+    list(FIND ${input2} ${it} index)
+    if( NOT (index EQUAL -1))
+      list(APPEND ${output} ${it})
+    endif()
+  endforeach()
+endmacro()

Modified: vendor/compiler-rt/dist/cmake/Modules/SanitizerUtils.cmake
==============================================================================
--- vendor/compiler-rt/dist/cmake/Modules/SanitizerUtils.cmake	Wed Dec 30 11:51:35 2015	(r292924)
+++ vendor/compiler-rt/dist/cmake/Modules/SanitizerUtils.cmake	Wed Dec 30 11:52:19 2015	(r292925)
@@ -4,46 +4,60 @@ set(SANITIZER_GEN_DYNAMIC_LIST
 set(SANITIZER_LINT_SCRIPT
   ${COMPILER_RT_SOURCE_DIR}/lib/sanitizer_common/scripts/check_lint.sh)
 
 # Create a target "<name>-symbols" that would generate the list of symbols
 # that need to be exported from sanitizer runtime "<name>". Function
 # interceptors are exported automatically, user can also provide files with
 # symbol names that should be exported as well.
-#   add_sanitizer_rt_symbols(<name> <files with extra symbols to export>)
+#   add_sanitizer_rt_symbols(<name>
+#                            ARCHS <architectures>
+#                            PARENT_TARGET <convenience parent target>
+#                            EXTRA <files with extra symbols to export>)
 macro(add_sanitizer_rt_symbols name)
-  set(stamp ${CMAKE_CURRENT_BINARY_DIR}/${name}.syms-stamp)
-  set(extra_args)
-  foreach(arg ${ARGN})
-    list(APPEND extra_args "--extra" ${arg})
-  endforeach()
-  add_custom_command(OUTPUT ${stamp}
-    COMMAND ${PYTHON_EXECUTABLE}
-      ${SANITIZER_GEN_DYNAMIC_LIST} ${extra_args} $<TARGET_FILE:${name}>
-      > $<TARGET_FILE:${name}>.syms
-    COMMAND ${CMAKE_COMMAND} -E touch ${stamp}
-    DEPENDS ${name} ${SANITIZER_GEN_DYNAMIC_LIST} ${ARGN}
-    WORKING_DIRECTORY ${CMAKE_CURRENT_SOURCE_DIR}
-    COMMENT "Generating exported symbols for ${name}"
-    VERBATIM)
-  add_custom_target(${name}-symbols ALL
-    DEPENDS ${stamp}
-    SOURCES ${SANITIZER_GEN_DYNAMIC_LIST} ${ARGN})
-
-  if(NOT CMAKE_VERSION VERSION_LESS 3.0)
-    install(FILES $<TARGET_FILE:${name}>.syms
-            DESTINATION ${COMPILER_RT_LIBRARY_INSTALL_DIR})
-  else()
-    # Per-config install location.
-    if(CMAKE_CONFIGURATION_TYPES)
-      foreach(c ${CMAKE_CONFIGURATION_TYPES})
-        get_target_property(libfile ${name} LOCATION_${c})
-        install(FILES ${libfile}.syms CONFIGURATIONS ${c}
-          DESTINATION ${COMPILER_RT_LIBRARY_INSTALL_DIR})
-      endforeach()
+  cmake_parse_arguments(ARG
+    ""
+    "PARENT_TARGET"
+    "ARCHS;EXTRA"
+    ${ARGN})
+  foreach(arch ${ARG_ARCHS})
+    set(target_name ${name}-${arch})
+    set(stamp ${CMAKE_CURRENT_BINARY_DIR}/${target_name}.syms-stamp)
+    set(extra_args)
+    foreach(arg ${ARG_EXTRA})
+      list(APPEND extra_args "--extra" ${arg})
+    endforeach()
+    add_custom_command(OUTPUT ${stamp}
+      COMMAND ${PYTHON_EXECUTABLE}
+        ${SANITIZER_GEN_DYNAMIC_LIST} ${extra_args} $<TARGET_FILE:${target_name}>
+        > $<TARGET_FILE:${target_name}>.syms
+      COMMAND ${CMAKE_COMMAND} -E touch ${stamp}
+      DEPENDS ${target_name} ${SANITIZER_GEN_DYNAMIC_LIST} ${ARG_EXTRA}
@@ -4,46 +4,60 @@ set(SANITIZER_GEN_DYNAMIC_LIST
   ${COMPILER_RT_SOURCE_DIR}/lib/sanitizer_common/scripts/check_lint.sh)
 
-# Create a target "<name>-symbols" that would generate the list of symbols
-# that need to be exported from sanitizer runtime "<name>". Function
+# Create a target "<name>-<arch>-symbols" that would generate the list of
+# symbols that need to be exported from sanitizer runtime "<name>". Function
 # interceptors are exported automatically, user can also provide files with
 # symbol names that should be exported as well.

*** DIFF OUTPUT TRUNCATED AT 1000 LINES ***


More information about the svn-src-all mailing list